"""Tests for hypothesis generation engine — all 10 detectors and public API."""

from __future__ import annotations

from typing import Any

import pytest

from llmdebug.hypotheses import Hypothesis, format_hypotheses_text, generate_hypotheses

# ---------------------------------------------------------------------------
# Helpers
# ---------------------------------------------------------------------------


def _snap(
    exc_type: str = "Exception",
    exc_msg: str = "",
    locals_: dict[str, Any] | None = None,
    locals_meta: dict[str, Any] | None = None,
    crash_frame_index: int = 0,
) -> dict[str, Any]:
    """Build a minimal snapshot dict for testing detectors."""
    return {
        "exception": {"type": exc_type, "message": exc_msg},
        "frames": [
            {
                "file": "/code/app.py",
                "file_rel": "app.py",
                "line": 10,
                "function": "do_stuff",
                "locals": locals_ or {},
                "locals_meta": locals_meta or {},
            },
        ],
        "crash_frame_index": crash_frame_index,
    }


# ---------------------------------------------------------------------------
# 1. empty_array detector
# ---------------------------------------------------------------------------


class TestDetectEmptyArray:
    def test_shape_zero_triggers(self) -> None:
        snap = _snap(locals_={"data": {"__array__": True, "shape": [0, 5], "dtype": "float64"}})
        hyps = generate_hypotheses(snap)
        matching = [h for h in hyps if h.pattern == "empty_array"]
        assert len(matching) == 1
        h = matching[0]
        assert h.confidence == 0.85
        assert "data" in h.description
        assert "shape [0, 5]" in h.description
        assert "data.shape = [0, 5]" in h.evidence

    def test_non_empty_array_no_trigger(self) -> None:
        snap = _snap(locals_={"data": {"__array__": True, "shape": [10, 5], "dtype": "float64"}})
        hyps = generate_hypotheses(snap)
        matching = [h for h in hyps if h.pattern == "empty_array"]
        assert len(matching) == 0

    def test_no_shape_key_no_trigger(self) -> None:
        snap = _snap(locals_={"data": {"__array__": True}})
        hyps = generate_hypotheses(snap)
        matching = [h for h in hyps if h.pattern == "empty_array"]
        assert len(matching) == 0

    def test_scalar_locals_no_trigger(self) -> None:
        snap = _snap(locals_={"x": 42, "y": "hello"})
        hyps = generate_hypotheses(snap)
        matching = [h for h in hyps if h.pattern == "empty_array"]
        assert len(matching) == 0

    def test_no_frames_no_trigger(self) -> None:
        snap: dict[str, Any] = {
            "exception": {"type": "RuntimeError", "message": "fail"},
            "frames": [],
        }
        hyps = generate_hypotheses(snap)
        matching = [h for h in hyps if h.pattern == "empty_array"]
        assert len(matching) == 0

    def test_dataframe_summary_empty(self) -> None:
        snap = _snap(locals_={"df": {"__dataframe__": True, "shape": [0, 3]}})
        hyps = generate_hypotheses(snap)
        matching = [h for h in hyps if h.pattern == "empty_array"]
        assert len(matching) == 1

    def test_series_summary_empty(self) -> None:
        snap = _snap(locals_={"s": {"__series__": True, "shape": [0]}})
        hyps = generate_hypotheses(snap)
        matching = [h for h in hyps if h.pattern == "empty_array"]
        assert len(matching) == 1


# ---------------------------------------------------------------------------
# 2. shape_mismatch detector
# ---------------------------------------------------------------------------


class TestDetectShapeMismatch:
    def test_value_error_with_shape_keyword_and_two_arrays(self) -> None:
        snap = _snap(
            exc_type="ValueError",
            exc_msg="operands could not be broadcast together with shapes (3,4) and (5,6)",
            locals_={
                "a": {"__array__": True, "shape": [3, 4], "dtype": "float64"},
                "b": {"__array__": True, "shape": [5, 6], "dtype": "float64"},
            },
        )
        hyps = generate_hypotheses(snap)
        matching = [h for h in hyps if h.pattern == "shape_mismatch"]
        assert len(matching) == 1
        h = matching[0]
        assert h.confidence == 0.9
        assert "a.shape = [3, 4]" in h.evidence
        assert "b.shape = [5, 6]" in h.evidence

    def test_runtime_error_with_dimension_keyword(self) -> None:
        snap = _snap(
            exc_type="RuntimeError",
            exc_msg="dimension mismatch at index 1",
            locals_={
                "x": {"__array__": True, "shape": [10, 3], "dtype": "float32"},
                "y": {"__array__": True, "shape": [10, 7], "dtype": "float32"},
            },
        )
        hyps = generate_hypotheses(snap)
        matching = [h for h in hyps if h.pattern == "shape_mismatch"]
        assert len(matching) == 1

    def test_wrong_exc_type_no_trigger(self) -> None:
        snap = _snap(
            exc_type="TypeError",
            exc_msg="shape mismatch",
            locals_={
                "a": {"__array__": True, "shape": [3, 4], "dtype": "float64"},
                "b": {"__array__": True, "shape": [5, 6], "dtype": "float64"},
            },
        )
        hyps = generate_hypotheses(snap)
        matching = [h for h in hyps if h.pattern == "shape_mismatch"]
        assert len(matching) == 0

    def test_no_shape_keyword_in_message_no_trigger(self) -> None:
        snap = _snap(
            exc_type="ValueError",
            exc_msg="something completely unrelated",
            locals_={
                "a": {"__array__": True, "shape": [3, 4], "dtype": "float64"},
                "b": {"__array__": True, "shape": [5, 6], "dtype": "float64"},
            },
        )
        hyps = generate_hypotheses(snap)
        matching = [h for h in hyps if h.pattern == "shape_mismatch"]
        assert len(matching) == 0

    def test_only_one_array_no_trigger(self) -> None:
        snap = _snap(
            exc_type="ValueError",
            exc_msg="shape mismatch",
            locals_={
                "a": {"__array__": True, "shape": [3, 4], "dtype": "float64"},
                "x": 42,
            },
        )
        hyps = generate_hypotheses(snap)
        matching = [h for h in hyps if h.pattern == "shape_mismatch"]
        assert len(matching) == 0

    def test_size_keyword_triggers(self) -> None:
        snap = _snap(
            exc_type="ValueError",
            exc_msg="size of tensor a (10) must match the size of tensor b (20)",
            locals_={
                "a": {"__array__": True, "shape": [10], "dtype": "float32"},
                "b": {"__array__": True, "shape": [20], "dtype": "float32"},
            },
        )
        hyps = generate_hypotheses(snap)
        matching = [h for h in hyps if h.pattern == "shape_mismatch"]
        assert len(matching) == 1


# ---------------------------------------------------------------------------
# 3. none_dereference detector
# ---------------------------------------------------------------------------


class TestDetectNoneDereference:
    def test_attribute_error_with_none_local(self) -> None:
        snap = _snap(
            exc_type="AttributeError",
            exc_msg="'NoneType' object has no attribute 'strip'",
            locals_={"result": None, "x": 42},
        )
        hyps = generate_hypotheses(snap)
        matching = [h for h in hyps if h.pattern == "none_dereference"]
        assert len(matching) == 1
        h = matching[0]
        assert h.confidence == 0.9  # boosted because "NoneType" in msg
        assert "result" in h.description

    def test_type_error_with_none_local(self) -> None:
        snap = _snap(
            exc_type="TypeError",
            exc_msg="argument of type 'NoneType' is not iterable",
            locals_={"config": None},
        )
        hyps = generate_hypotheses(snap)
        matching = [h for h in hyps if h.pattern == "none_dereference"]
        assert len(matching) == 1
        assert matching[0].confidence == 0.9

    def test_lower_confidence_without_nonetype_in_message(self) -> None:
        snap = _snap(
            exc_type="AttributeError",
            exc_msg="object has no attribute 'foo'",
            locals_={"obj": None},
        )
        hyps = generate_hypotheses(snap)
        matching = [h for h in hyps if h.pattern == "none_dereference"]
        assert len(matching) == 1
        assert matching[0].confidence == 0.75

    def test_confidence_boost_with_quoted_none(self) -> None:
        snap = _snap(
            exc_type="TypeError",
            exc_msg="unsupported operand type(s): 'None' and 'int'",
            locals_={"val": None},
        )
        hyps = generate_hypotheses(snap)
        matching = [h for h in hyps if h.pattern == "none_dereference"]
        assert len(matching) == 1
        assert matching[0].confidence == 0.9  # "'None'" in msg

    def test_no_none_locals_no_trigger(self) -> None:
        snap = _snap(
            exc_type="AttributeError",
            exc_msg="'NoneType' object has no attribute 'strip'",
            locals_={"result": "hello", "x": 42},
        )
        hyps = generate_hypotheses(snap)
        matching = [h for h in hyps if h.pattern == "none_dereference"]
        assert len(matching) == 0

    def test_wrong_exc_type_no_trigger(self) -> None:
        snap = _snap(
            exc_type="ValueError",
            exc_msg="some error",
            locals_={"result": None},
        )
        hyps = generate_hypotheses(snap)
        matching = [h for h in hyps if h.pattern == "none_dereference"]
        assert len(matching) == 0

    def test_multiple_none_vars_listed(self) -> None:
        snap = _snap(
            exc_type="AttributeError",
            exc_msg="'NoneType' object has no attribute 'x'",
            locals_={"a": None, "b": None, "c": 99},
        )
        hyps = generate_hypotheses(snap)
        matching = [h for h in hyps if h.pattern == "none_dereference"]
        assert len(matching) == 1
        h = matching[0]
        assert "a" in h.description
        assert "b" in h.description
        assert len(h.evidence) == 2


# ---------------------------------------------------------------------------
# 4. off_by_one detector
# ---------------------------------------------------------------------------


class TestDetectOffByOne:
    def test_index_equals_list_length(self) -> None:
        snap = _snap(
            exc_type="IndexError",
            exc_msg="list index out of range",
            locals_={"i": 5, "items": [1, 2, 3, 4, 5]},
        )
        hyps = generate_hypotheses(snap)
        matching = [h for h in hyps if h.pattern == "off_by_one"]
        assert len(matching) == 1
        h = matching[0]
        assert h.confidence == 0.9
        assert "i" in h.description
        assert "items" in h.description
        assert "i = 5" in h.evidence
        assert "len(items) = 5" in h.evidence

    def test_index_equals_array_shape0(self) -> None:
        snap = _snap(
            exc_type="IndexError",
            exc_msg="index 10 is out of bounds for axis 0 with size 10",
            locals_={
                "idx": 10,
                "arr": {"__array__": True, "shape": [10, 3], "dtype": "float64"},
            },
        )
        hyps = generate_hypotheses(snap)
        matching = [h for h in hyps if h.pattern == "off_by_one"]
        assert len(matching) == 1

    def test_index_less_than_length_no_trigger(self) -> None:
        snap = _snap(
            exc_type="IndexError",
            exc_msg="list index out of range",
            locals_={"i": 3, "items": [1, 2, 3, 4, 5]},
        )
        hyps = generate_hypotheses(snap)
        matching = [h for h in hyps if h.pattern == "off_by_one"]
        assert len(matching) == 0

    def test_wrong_exc_type_no_trigger(self) -> None:
        snap = _snap(
            exc_type="ValueError",
            exc_msg="index out of range",
            locals_={"i": 5, "items": [1, 2, 3, 4, 5]},
        )
        hyps = generate_hypotheses(snap)
        matching = [h for h in hyps if h.pattern == "off_by_one"]
        assert len(matching) == 0

    def test_no_int_vars_no_trigger(self) -> None:
        snap = _snap(
            exc_type="IndexError",
            exc_msg="list index out of range",
            locals_={"items": [1, 2, 3]},
        )
        hyps = generate_hypotheses(snap)
        matching = [h for h in hyps if h.pattern == "off_by_one"]
        assert len(matching) == 0

    def test_string_length_match(self) -> None:
        snap = _snap(
            exc_type="IndexError",
            exc_msg="string index out of range",
            locals_={"pos": 3, "text": "abc"},
        )
        hyps = generate_hypotheses(snap)
        matching = [h for h in hyps if h.pattern == "off_by_one"]
        assert len(matching) == 1
        assert "pos" in matching[0].description
        assert "text" in matching[0].description


# ---------------------------------------------------------------------------
# 5. nan_inf_anomaly detector
# ---------------------------------------------------------------------------


class TestDetectNanInf:
    def test_nan_in_anomalies(self) -> None:
        snap = _snap(
            locals_={
                "weights": {"__array__": True, "shape": [100], "anomalies": {"nan": 5, "inf": 0}},
            }
        )
        hyps = generate_hypotheses(snap)
        matching = [h for h in hyps if h.pattern == "nan_inf_anomaly"]
        assert len(matching) == 1
        h = matching[0]
        assert h.confidence == 0.85
        assert "5 NaN" in h.description
        assert "Inf" not in h.description  # inf count is 0

    def test_inf_in_anomalies(self) -> None:
        snap = _snap(
            locals_={
                "loss": {"__array__": True, "shape": [1], "anomalies": {"nan": 0, "inf": 2}},
            }
        )
        hyps = generate_hypotheses(snap)
        matching = [h for h in hyps if h.pattern == "nan_inf_anomaly"]
        assert len(matching) == 1
        assert "2 Inf" in matching[0].description

    def test_both_nan_and_inf(self) -> None:
        snap = _snap(
            locals_={
                "data": {"anomalies": {"nan": 3, "inf": 7}},
            }
        )
        hyps = generate_hypotheses(snap)
        matching = [h for h in hyps if h.pattern == "nan_inf_anomaly"]
        assert len(matching) == 1
        h = matching[0]
        assert "3 NaN" in h.description
        assert "7 Inf" in h.description

    def test_zero_counts_no_trigger(self) -> None:
        snap = _snap(
            locals_={
                "data": {"anomalies": {"nan": 0, "inf": 0}},
            }
        )
        hyps = generate_hypotheses(snap)
        matching = [h for h in hyps if h.pattern == "nan_inf_anomaly"]
        assert len(matching) == 0

    def test_no_anomalies_key_no_trigger(self) -> None:
        snap = _snap(
            locals_={
                "data": {"__array__": True, "shape": [10, 5]},
            }
        )
        hyps = generate_hypotheses(snap)
        matching = [h for h in hyps if h.pattern == "nan_inf_anomaly"]
        assert len(matching) == 0

    def test_non_dict_value_no_trigger(self) -> None:
        snap = _snap(locals_={"x": 42, "y": "hello"})
        hyps = generate_hypotheses(snap)
        matching = [h for h in hyps if h.pattern == "nan_inf_anomaly"]
        assert len(matching) == 0


# ---------------------------------------------------------------------------
# 6. type_mismatch detector
# ---------------------------------------------------------------------------


class TestDetectTypeMismatch:
    def test_type_in_message_with_locals_meta(self) -> None:
        snap = _snap(
            exc_type="TypeError",
            exc_msg="unsupported operand type(s) for +: 'int' and 'str'",
            locals_={"name": "alice", "count": 5},
            locals_meta={"name": {"type": "str"}, "count": {"type": "int"}},
        )
        hyps = generate_hypotheses(snap)
        matching = [h for h in hyps if h.pattern == "type_mismatch"]
        assert len(matching) == 1
        h = matching[0]
        assert h.confidence == 0.8
        # "str" appears in the message and is the type of "name"
        assert "name" in h.description or "count" in h.description

    def test_no_type_in_message_no_trigger(self) -> None:
        snap = _snap(
            exc_type="TypeError",
            exc_msg="missing 1 required positional argument",
            locals_={"x": 42},
            locals_meta={"x": {"type": "int"}},
        )
        hyps = generate_hypotheses(snap)
        matching = [h for h in hyps if h.pattern == "type_mismatch"]
        assert len(matching) == 0

    def test_wrong_exc_type_no_trigger(self) -> None:
        snap = _snap(
            exc_type="ValueError",
            exc_msg="int is not valid",
            locals_={"x": 42},
            locals_meta={"x": {"type": "int"}},
        )
        hyps = generate_hypotheses(snap)
        matching = [h for h in hyps if h.pattern == "type_mismatch"]
        assert len(matching) == 0

    def test_no_locals_meta_no_trigger(self) -> None:
        snap = _snap(
            exc_type="TypeError",
            exc_msg="unsupported operand type(s) for +: 'int' and 'str'",
            locals_={"name": "alice"},
            locals_meta={},
        )
        hyps = generate_hypotheses(snap)
        matching = [h for h in hyps if h.pattern == "type_mismatch"]
        assert len(matching) == 0

    def test_evidence_includes_message(self) -> None:
        snap = _snap(
            exc_type="TypeError",
            exc_msg="expected list got tuple",
            locals_={"items": (1, 2)},
            locals_meta={"items": {"type": "tuple"}},
        )
        hyps = generate_hypotheses(snap)
        matching = [h for h in hyps if h.pattern == "type_mismatch"]
        assert len(matching) == 1
        assert any("message:" in e for e in matching[0].evidence)


# ---------------------------------------------------------------------------
# 7. key_not_found detector
# ---------------------------------------------------------------------------


class TestDetectKeyNotFound:
    def test_key_error_with_dict_local(self) -> None:
        snap = _snap(
            exc_type="KeyError",
            exc_msg="'color'",
            locals_={"config": {"name": "test", "size": 10}},
        )
        hyps = generate_hypotheses(snap)
        matching = [h for h in hyps if h.pattern == "key_not_found"]
        assert len(matching) == 1
        h = matching[0]
        assert h.confidence == 0.85
        assert "'color'" in h.description
        assert "config" in h.description
        assert "name, size" in h.evidence[1]

    def test_no_dict_locals_no_trigger(self) -> None:
        snap = _snap(
            exc_type="KeyError",
            exc_msg="'missing'",
            locals_={"x": 42, "y": "text"},
        )
        hyps = generate_hypotheses(snap)
        matching = [h for h in hyps if h.pattern == "key_not_found"]
        assert len(matching) == 0

    def test_wrong_exc_type_no_trigger(self) -> None:
        snap = _snap(
            exc_type="ValueError",
            exc_msg="'missing'",
            locals_={"d": {"a": 1}},
        )
        hyps = generate_hypotheses(snap)
        matching = [h for h in hyps if h.pattern == "key_not_found"]
        assert len(matching) == 0

    def test_suggestion_mentions_get(self) -> None:
        snap = _snap(
            exc_type="KeyError",
            exc_msg="'k'",
            locals_={"d": {"a": 1}},
        )
        hyps = generate_hypotheses(snap)
        matching = [h for h in hyps if h.pattern == "key_not_found"]
        assert len(matching) == 1
        assert ".get(" in matching[0].suggestion

    def test_large_dict_truncates_keys(self) -> None:
        big_dict = {f"key_{i}": i for i in range(20)}
        snap = _snap(
            exc_type="KeyError",
            exc_msg="'missing'",
            locals_={"data": big_dict},
        )
        hyps = generate_hypotheses(snap)
        matching = [h for h in hyps if h.pattern == "key_not_found"]
        assert len(matching) == 1
        # Only first 10 keys shown
        keys_evidence = matching[0].evidence[1]
        assert keys_evidence.count(",") <= 10


# ---------------------------------------------------------------------------
# 8. import_failure detector
# ---------------------------------------------------------------------------


class TestDetectImportFailure:
    def test_module_not_found_error(self) -> None:
        snap = _snap(
            exc_type="ModuleNotFoundError",
            exc_msg="No module named 'torch'",
        )
        hyps = generate_hypotheses(snap)
        matching = [h for h in hyps if h.pattern == "import_failure"]
        assert len(matching) == 1
        h = matching[0]
        assert h.confidence == 0.95
        assert "torch" in h.description
        assert "pip install torch" in h.suggestion

    def test_import_error(self) -> None:
        snap = _snap(
            exc_type="ImportError",
            exc_msg="No module named 'sklearn.ensemble'",
        )
        hyps = generate_hypotheses(snap)
        matching = [h for h in hyps if h.pattern == "import_failure"]
        assert len(matching) == 1
        h = matching[0]
        assert "sklearn.ensemble" in h.description
        # Suggestion uses the top-level package
        assert "pip install sklearn" in h.suggestion

    def test_wrong_exc_type_no_trigger(self) -> None:
        snap = _snap(
            exc_type="RuntimeError",
            exc_msg="No module named 'foo'",
        )
        hyps = generate_hypotheses(snap)
        matching = [h for h in hyps if h.pattern == "import_failure"]
        assert len(matching) == 0

    def test_non_standard_import_message(self) -> None:
        snap = _snap(
            exc_type="ImportError",
            exc_msg="cannot import name 'bar' from 'foo'",
        )
        hyps = generate_hypotheses(snap)
        matching = [h for h in hyps if h.pattern == "import_failure"]
        assert len(matching) == 1
        # Falls back to exc_msg since regex doesn't match "No module named"
        assert matching[0].description


# ---------------------------------------------------------------------------
# 9. file_not_found detector
# ---------------------------------------------------------------------------


class TestDetectFileNotFound:
    def test_file_not_found_error_with_path(self) -> None:
        snap = _snap(
            exc_type="FileNotFoundError",
            exc_msg="[Errno 2] No such file or directory: '/data/input.csv'",
        )
        hyps = generate_hypotheses(snap)
        matching = [h for h in hyps if h.pattern == "file_not_found"]
        assert len(matching) == 1
        h = matching[0]
        assert h.confidence == 0.95
        assert "/data/input.csv" in h.description
        assert "/data/input.csv" in h.suggestion

    def test_wrong_exc_type_no_trigger(self) -> None:
        snap = _snap(
            exc_type="IOError",
            exc_msg="file not found: '/data/input.csv'",
        )
        hyps = generate_hypotheses(snap)
        matching = [h for h in hyps if h.pattern == "file_not_found"]
        assert len(matching) == 0

    def test_path_extraction_with_single_quotes(self) -> None:
        snap = _snap(
            exc_type="FileNotFoundError",
            exc_msg="No such file: 'config.yaml'",
        )
        hyps = generate_hypotheses(snap)
        matching = [h for h in hyps if h.pattern == "file_not_found"]
        assert len(matching) == 1
        assert "config.yaml" in matching[0].description

    def test_path_extraction_with_double_quotes(self) -> None:
        snap = _snap(
            exc_type="FileNotFoundError",
            exc_msg='No such file: "settings.json"',
        )
        hyps = generate_hypotheses(snap)
        matching = [h for h in hyps if h.pattern == "file_not_found"]
        assert len(matching) == 1
        assert "settings.json" in matching[0].description

    def test_no_quoted_path_fallback(self) -> None:
        snap = _snap(
            exc_type="FileNotFoundError",
            exc_msg="file missing",
        )
        hyps = generate_hypotheses(snap)
        matching = [h for h in hyps if h.pattern == "file_not_found"]
        assert len(matching) == 1
        assert "unknown" in matching[0].description


# ---------------------------------------------------------------------------
# 10. assertion_failure detector
# ---------------------------------------------------------------------------


class TestDetectAssertionFailure:
    def test_assertion_error_with_locals(self) -> None:
        snap = _snap(
            exc_type="AssertionError",
            exc_msg="",
            locals_={"expected": 10, "actual": 7},
        )
        hyps = generate_hypotheses(snap)
        matching = [h for h in hyps if h.pattern == "assertion_failure"]
        assert len(matching) == 1
        h = matching[0]
        assert h.confidence == 0.8
        assert "check variable values" in h.description.lower()
        # Evidence should contain the locals
        evidence_str = " ".join(h.evidence)
        assert "expected" in evidence_str
        assert "actual" in evidence_str

    def test_assertion_error_without_locals(self) -> None:
        snap = _snap(
            exc_type="AssertionError",
            exc_msg="",
            locals_={},
        )
        hyps = generate_hypotheses(snap)
        matching = [h for h in hyps if h.pattern == "assertion_failure"]
        assert len(matching) == 1
        h = matching[0]
        assert h.confidence == 0.7
        assert "no locals" in h.description.lower()
        assert "assertion messages" in h.suggestion.lower()

    def test_wrong_exc_type_no_trigger(self) -> None:
        snap = _snap(
            exc_type="RuntimeError",
            exc_msg="assertion failed",
            locals_={"x": 1},
        )
        hyps = generate_hypotheses(snap)
        matching = [h for h in hyps if h.pattern == "assertion_failure"]
        assert len(matching) == 0

    def test_limits_evidence_to_five_locals(self) -> None:
        many_locals = {f"var_{i}": i for i in range(10)}
        snap = _snap(
            exc_type="AssertionError",
            exc_msg="",
            locals_=many_locals,
        )
        hyps = generate_hypotheses(snap)
        matching = [h for h in hyps if h.pattern == "assertion_failure"]
        assert len(matching) == 1
        assert len(matching[0].evidence) <= 5

    def test_pytest_internals_filtered(self) -> None:
        snap = _snap(
            exc_type="AssertionError",
            exc_msg="",
            locals_={"@py_builtins": "<module>", "@py_assert0": True, "real_var": 42},
        )
        hyps = generate_hypotheses(snap)
        matching = [h for h in hyps if h.pattern == "assertion_failure"]
        assert len(matching) == 1
        h = matching[0]
        # pytest internals filtered out, only real_var remains
        evidence_str = " ".join(h.evidence)
        assert "@py_" not in evidence_str
        assert "real_var" in evidence_str


# ---------------------------------------------------------------------------
# generate_hypotheses — integration / orchestration
# ---------------------------------------------------------------------------


class TestGenerateHypotheses:
    def test_sorted_by_confidence_descending(self) -> None:
        """When multiple detectors fire, results are sorted highest confidence first."""
        snap = _snap(
            exc_type="AttributeError",
            exc_msg="'NoneType' object has no attribute 'shape'",
            locals_={
                "result": None,
                "data": {"__array__": True, "shape": [0, 5], "dtype": "float64"},
            },
        )
        hyps = generate_hypotheses(snap)
        assert len(hyps) >= 2
        for i in range(len(hyps) - 1):
            assert hyps[i].confidence >= hyps[i + 1].confidence

    def test_empty_snapshot_returns_empty(self) -> None:
        hyps = generate_hypotheses({})
        assert hyps == []

    def test_snapshot_with_no_frames_returns_empty(self) -> None:
        snap: dict[str, Any] = {
            "exception": {"type": "RuntimeError", "message": "some error"},
            "frames": [],
        }
        hyps = generate_hypotheses(snap)
        assert hyps == []

    def test_multiple_patterns_fire_together(self) -> None:
        """empty_array and none_dereference can co-exist."""
        snap = _snap(
            exc_type="AttributeError",
            exc_msg="'NoneType' object has no attribute 'sum'",
            locals_={
                "model": None,
                "data": {"__array__": True, "shape": [0, 10], "dtype": "float32"},
            },
        )
        hyps = generate_hypotheses(snap)
        patterns = {h.pattern for h in hyps}
        assert "empty_array" in patterns
        assert "none_dereference" in patterns

    def test_broken_detector_silently_skipped(self) -> None:
        """A detector that raises is silently caught."""
        from llmdebug.hypotheses import _detectors

        def _boom(snapshot: dict[str, Any]) -> list[Hypothesis]:
            raise RuntimeError("detector bug")

        _detectors.append(_boom)
        try:
            snap = _snap(
                exc_type="FileNotFoundError",
                exc_msg="No such file: 'x.txt'",
            )
            # Should not raise, and file_not_found should still work
            hyps = generate_hypotheses(snap)
            matching = [h for h in hyps if h.pattern == "file_not_found"]
            assert len(matching) == 1
        finally:
            _detectors.remove(_boom)

    def test_deduplication_keeps_first_by_pattern(self) -> None:
        """If two detectors emit the same pattern, only the first is kept."""
        from llmdebug.hypotheses import _detectors

        def _duplicate_file_detector(snapshot: dict[str, Any]) -> list[Hypothesis]:
            return [
                Hypothesis(
                    confidence=0.5,
                    pattern="file_not_found",
                    description="duplicate",
                    evidence=(),
                    suggestion="none",
                )
            ]

        _detectors.append(_duplicate_file_detector)
        try:
            snap = _snap(
                exc_type="FileNotFoundError",
                exc_msg="No such file: 'x.txt'",
            )
            hyps = generate_hypotheses(snap)
            file_hyps = [h for h in hyps if h.pattern == "file_not_found"]
            # Only one kept (first one wins)
            assert len(file_hyps) == 1
            assert file_hyps[0].confidence == 0.95  # original, not the 0.5 duplicate
        finally:
            _detectors.remove(_duplicate_file_detector)

    def test_crash_frame_index_respected(self) -> None:
        """Detector reads the correct frame based on crash_frame_index."""
        snap: dict[str, Any] = {
            "exception": {"type": "AssertionError", "message": ""},
            "frames": [
                {"locals": {"x": 1}, "locals_meta": {}},
                {"locals": {"target": 99, "actual": 0}, "locals_meta": {}},
            ],
            "crash_frame_index": 1,
        }
        hyps = generate_hypotheses(snap)
        matching = [h for h in hyps if h.pattern == "assertion_failure"]
        assert len(matching) == 1
        evidence_str = " ".join(matching[0].evidence)
        assert "target" in evidence_str
        assert "actual" in evidence_str
        # Should NOT include x from frame 0
        assert "x = 1" not in evidence_str


# ---------------------------------------------------------------------------
# format_hypotheses_text
# ---------------------------------------------------------------------------


class TestFormatHypothesesText:
    def test_empty_list_message(self) -> None:
        text = format_hypotheses_text([])
        assert "No hypotheses generated" in text

    def test_single_hypothesis_includes_all_fields(self) -> None:
        h = Hypothesis(
            confidence=0.85,
            pattern="empty_array",
            description="Variable 'data' is an empty array (shape [0, 5])",
            evidence=("data.shape = [0, 5]",),
            suggestion="Check why 'data' has no elements.",
        )
        text = format_hypotheses_text([h])
        assert "## Hypothesis #1 [85%]" in text
        assert "empty_array" in text
        assert "Variable 'data' is an empty array (shape [0, 5])" in text
        assert "Evidence:" in text
        assert "data.shape = [0, 5]" in text
        assert "Suggestion:" in text
        assert "Check why 'data' has no elements." in text

    def test_multiple_hypotheses_numbered(self) -> None:
        h1 = Hypothesis(
            confidence=0.95,
            pattern="import_failure",
            description="Cannot import 'torch'",
            evidence=("exception: ModuleNotFoundError",),
            suggestion="pip install torch",
        )
        h2 = Hypothesis(
            confidence=0.7,
            pattern="assertion_failure",
            description="Assertion failed",
            evidence=("x = 1",),
            suggestion="Check values.",
        )
        text = format_hypotheses_text([h1, h2])
        assert "## Hypothesis #1 [95%]" in text
        assert "## Hypothesis #2 [70%]" in text

    def test_confidence_is_integer_percent(self) -> None:
        h = Hypothesis(
            confidence=0.333,
            pattern="test",
            description="test",
            evidence=(),
            suggestion="test",
        )
        text = format_hypotheses_text([h])
        assert "[33%]" in text

    def test_multiple_evidence_items(self) -> None:
        h = Hypothesis(
            confidence=0.9,
            pattern="off_by_one",
            description="off by one",
            evidence=("i = 5", "len(items) = 5"),
            suggestion="fix index",
        )
        text = format_hypotheses_text([h])
        assert "  - i = 5" in text
        assert "  - len(items) = 5" in text


# ---------------------------------------------------------------------------
# Hypothesis dataclass
# ---------------------------------------------------------------------------


class TestHypothesisDataclass:
    def test_frozen(self) -> None:
        h = Hypothesis(
            confidence=0.9,
            pattern="test",
            description="desc",
            evidence=("e1",),
            suggestion="fix it",
        )
        with pytest.raises(AttributeError):
            h.confidence = 0.5  # type: ignore[misc]

    def test_fields(self) -> None:
        h = Hypothesis(
            confidence=0.75,
            pattern="none_dereference",
            description="Variable 'x' is None",
            evidence=("x = None",),
            suggestion="Check init",
        )
        assert h.confidence == 0.75
        assert h.pattern == "none_dereference"
        assert h.description == "Variable 'x' is None"
        assert h.evidence == ("x = None",)
        assert h.suggestion == "Check init"



n, l, r = map(int, input().split())

z = format(n, "b")
z = int(z)
s = list(str(z))
m = len(s)
ans = 0

for i in range(m):
    if n >> i & 1 == 1:
        if 2**i <= l < r < 2 ** (i + 1):
            ans += r - l + 1
        elif 2**i < l < 2 ** (i + 1):
            ans += 2 ** (i + 1) - l
        elif 2**i <= r < 2 ** (i + 1):
            ans += r - 2**i + 1
        else:
            ans += 2**i

print(ans)



def hantei(N, A):
    for n1 in range(N):
        for n2 in range(N):
            if (
                (A[n1][n2] == "-" and A[n2][n1] == "-")
                or (A[n1][n2] == "W" and A[n2][n1] == "L")
                or (A[n1][n2] == "L" and A[n2][n1] == "W")
                or (A[n1][n2] == "D" and A[n2][n1] == "D")
            ):
                continue
            else:
                return "incorrect"
    return "correnct"


N = int(input())
A = []

for _ in range(N):
    A.append(list(str(input())))

print(hantei(N, A))



import subprocess
import sys


def test_condefects_0():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='3\n-xx\no-x\noo-\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '3 2 1\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_1():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='7\n-oxoxox\nx-xxxox\noo-xoox\nxoo-ooo\nooxx-ox\nxxxxx-x\noooxoo-\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '4 7 3 1 5 2 6\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_2():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='100\n-oxxooooooxxxxoxoxoxooooxxooxxxxoxoxoxoxxxoxxoxooxxxooooxxoooooooxoxxxooxxxxxooooxooxoxxoooxxxoxxoxo\nx-ooxooxxoxooxxxxoxooxxoooxxoooxoxooooooxoxoxxxoxooooxxoxxooxxxxoxxxoxxoxxoooxoxxoxxoooxxxxoxxooxoxo\nox-xooxxooxxxxxxoxooooxooxooxxoxxxoxxooooxxoxooxxoxoxooxxoxxxooxxoxoxooxxoxxxxoxoxoxoxoxooxxxxoxooox\noxo-ooxoxoooxoxxxxoxoxooxxxooxxxoxoxooxxxxoxxxoxoooxxoxxooxoxooxooxooxxxoxxxooooooooxxxoxoxooooxooxo\nxoxx-xxoxoxooooxooxooxxxxoooxxooxxxooxxoxxoxxoooxxoxxxoooooxxxxxooxxxxxoxooooooxoooooxooxxoooxxoooxx\nxxxxo-xxxooooxxoooooxxoxoxoxxxxxxxooooxxxooxooooxxxoooxxxooxxoxxxoxxoxxxxxoxoxxoxoxoooxxxxxoxxooxoxo\nxxoooo-xxxxxoxxxxooxxxxxoxoxooooooxxooxooxxoxxooxoxoxoxxoxxxxxoooooxoooooxoooooxxxxooooooxoxooxxxxxx\nxooxxoo-oooxxxoooxxoxoxxoxxxxxxoxoxoxxxoxxxxooxxoxoxoxooooxxoxxxxooxxoxoxooxoooxooxoooooxoooxxoooxoo\nxoxoooox-oxoxxxooxxooooxxoxxxxxoxooxxxxoxoxxoooxoooxoooxxxoxxxooooxxxxoxoooxoooxxoooooxxoxxxxxxxxooo\nxxxxxxoxx-xooxxoxxxxxooxxxxoxxooxooxoxooxoxooxxooxoooxoxooxooxoxoooxoxxoxoxxxxoxxxxooxxoxoxxxxxoxoxx\noooxoxoxoo-oxoxoxooxxxoxooxxxxxooooxxxxoxoxoxooxxxoxxxxxxxxxxxxoxoxoxooxxxoooxxxooxxxooxooxoxoooxxxo\noxoxxxooxxx-oxxooooxxoooxxoxxoxxxxoxooxxooooxxoxoxxooxoooooxooooxxoxoxxooxoooooooooxxoooxxxxoxxxxoxx\noxooxxxooxox-oooooooxxxxoxxooxxxoooxxoxxoxooxxxooxxxoxooxxxxxxooxxxxooooxooxxxxxoxoxxxxooxxoooxoooxx\noooxxoooooxox-ooooxoxxooxoxxxooxxxxoxoxoxoooxxooooxxxxooxoxxxxxxxxooxxxxooooxxooxxxoxoooxxoxoxoooxxx\nxoooxooxooooxx-oxoxxoxooxoooxxoxxoxooxoxoxxxooooooxoxoooxxxxooxxxxoxoxxooooxoxxoxooxoxxxooxoxxxxxoxo\noooooxoxxxxxxxx-xoxxooxxxxoxxxooxoxoooooxoxxxooxxxxoxoxxooxxoxxxooxooxxxoxoxxooxoooxxoxoxxooxooooxox\nxoxoxxoxxooxxxoo-xxxoxxoooxxxxxxoooxooxxxoxoooooxxooooxxoxxooxxooxxxxxoxxxxxxooxxoxxxxxoxoxoxoxoxxoo\noxooxxxoooxxxxxxo-oooooxoxooxoooxxxxxooxoxxxoxooxooxxxoxoxxxxoooooxxoxoxoxxooxoxooxxooooooooxxxxxoxo\nxoxxoxxoooxxxoooox-xxxoxoxxxxxooxxooxxoxooxoxoooxxooxoxoxxoxoxxoxxxxoxxxooooxoxxoxxxoxxxxoxxooxoooxo\noxxoxxoxxoooxxoooxo-xoxxoxoxxxoooxxxooooxxoooxxoxooooxxxoxoxxxoxxxxxxxoxxooooxxxxooxoooxxooxxxxoooox\nxxxxxoooxoooooxxxxoo-ooooxxxxoxxxoooxxxooooooxoooxooxoxxxoxoooxoxooxooooxxoxxxoxxooxoxxxxoxxooxxooxx\nxoxooooxxxoxoooxoxoxx-xxxoooxoooxxoxxoxxooooxoxooooxooxoooxxxxxxoxxoxooxoxxxxxoxoxxxoooxooxoxoxoooox\nxooxoxooxxxxoxxooxxoxo-oxxooxxxooxxooooooxoooxxoooxxxoxxoxoxoooxxoooxoxxxxxooxxooxxxxoooxxxxooooxxxo\nxxxxoooooooxoxxoxoooxox-oxxoooxoxxoxoxoxoxxooxoxoooxooxooxoxxooxxxoxooxoxxoooxoxxoxxxxooxxoxoxxxoxox\noxxooxxxooxoxoooxxxxxoox-xoxoxoxxooxxxooxoxxoxoooooxxxxxoooooooooxxxxooxxxooxxoxoxoooxoxoxxooooxoxox\noxooxoooxoxooxxoxooooxooo-xxooxooxxoxxooxoooooooxoooxoooxoxooooxoxxoooxooxxxxxxooxxoxoooxooxxxxoxxox\nxoxoxxxooooxooxxoxoxoxxoxo-oxxxoooooxxoxxooxxooxxooxoooxoooxxxxxooxooooooxoxxxxxoxxxoxxxoxoxoxxxxxox\nxoxxxooooxooxoxooxoooxxxoox-oooxxooxxxxxooooxxoxxxxxoxxooxxxooxooooxoxooxoooxxxxxxxxoooxoxoxxxoxxoxx\noxoxooxoooooxooooooooooxxxox-ooxxoxoxxxooxoxooxxxxoooxxxoooxxooxoxooxxxxxoooxxoxoxoxoxxooxoxoxxoxoxo\noxooooxooooxoxoooxooxxoxoxoxx-xxooooooxoxxxoxxxxxoooxooxoxxooxoxxxxoxxxxooxxoxoxxoooooxoxoxoxoxxoxoo\noxxoxoxooxoooxxxoxxxoxooxooxxo-xoooxxoxxoooxoooxxoooxxooxoxxoxoooxooooxooxxxoxooxooxxxoxoxoxxoxxxooo\nooooxoxxxxxooooxoxxxoxxxoxxoooo-xxxxooxxxxooxxxoxoxxoxoooooooxxxxoxoxxxooxxoooxxoxooxooxxxoxxxoxooox\nxxoxooxoooxoxoooxooxooxooxxooxxo-xoooxoxxooxxxoxooxxxoxxooxoxxxoxooxoooxooxxoxxoooxxoxxxxoxooxooxooo\nooooooxxxxxoxoxxxoooxoooxoxxxxxoo-ooxooxxxxxxoxxooooooooxoooooxooooooooxoxxxxoxxoxoooxooooxoxoxxoxoo\nxxxxoxooxxxxxoooxoxoxxoxxoxxoxxoxx-xxooxxooxoxxxoxxoxxoxxooxooxxxooxoxxxxooxoxooxxooooxoooooooxoxoxx\noxooxxoxoooooxxxooxoxoxooxxoxxooxxo-oxooooxoxxooooxooxoxxxxxooxxoxooxoxxoooxoxxoxxoxooxxoooxxxxooxxx\nxxoxxxxooxoxooxxxooxooxxoooooxoxxoox-xxooooooxxoooxxoxxoooxooxxoxxxoxxxxxooxxoxooooooxooxoooxxoxooxo\noxxxoxxooooxxxoxxxoxoxxooooooxxxoxxoo-xxooooooxooxxxoxxxxoxooxxxxxxoxoxxooxooxxooxxooxxxxxoooooxxoxx\nxxxooooooxooooxxoxxxooxxxxxoooooxxxxoo-ooxxoxooxoxoxxxoxooxoooxoxoxooooxooxxoooxoxooxoxxxxxxooooooxo\noxxoxoxxxxxooxoxoooxxoxoxxooxxoooooxxox-xoxxxoxxoxxxooxoxoxooxxxoxxoooxoooooooooxxxooxoxxxxxxoxooxoo\nooxoooxooooxxoxooxxoxxxxoooxxoxooooxxxxo-xooxoxooxxxxxxooooxoxxxxooooxooooooxxxoxoxoxooxxoxoxxxxoxoo\noxoooxooxxxxoxoxxoxoxxooxxxxooxoxoxxxxoxo-xxxxxooooooooooxoxoxoooooooxooxxooxoxxoxxxxoooxxoxooooxoxx\nxooxxxoooooxxxoooooxxxxooxxxxoxxxoxoxxooxo-oxooxooxoooxxxooxxxoxooxxxxxoxoooxxxxoxxoxxxxoxxoooooxxxx\noxxoooxooxxxxxooxoxxxxxxoxoxoxoxoooxxxxoxox-xxxxoxxxoxoxxoooxxxxooooooxoxxxooooxoxxxooxxoooxxoxxoxxo\noooooxoxxxooooxoxxoxxoxxxxooxoxoooxoxxoooooo-oxoooooooxxxooxooxoxxxoxooxxxoxxxxxooxooxxxxooxxxxxxoxx\nxoxoxxoxxoxoooxxxoxooxoooxxoxoxooxoooxxxxoxox-oooxxxooxoooooxoxoxoxooxoxooxxxxxxxxxxooxxxooxooxoxxox\nooxxxxxoxoxxoxxxxxxoxooxxxxxooxoxooxooxoooxoox-xoxooxooxoooxoxoooxxxooxooxxxoxoxooxoxoxxxooxxoooxxoo\nxxooxxxooxooxxxoxxxxxxxoxxoooooxoooxxxooxxooxxo-oooooxooxoxxoxoxoxxxxoxxooxxxooxoxxxoxxoxxxxxoxxxoox\nxooxoooxxxoxxxxoooooxxxxxoooooooxxxxxxxxxxxxxxxx-ooxxxoxxxxoxxxoxoxooxxoxxooooooxooxoxoxxxoxooxxxxxx\noxxxooxoxooooxxooxoxoxxxxxxooxxxxxoxxooooxxoxooxx-xxxoxoxxxxxoooooxooooxxxoxooxxxoxxxoxxooxoxxoxooox\noxoxxooxxxxoooooxxxxxxoxxxxoxxxooxooooxooxooxoxxxo-oooxxoxooxxxoxoxxxxxoooxxxoxoxxxooxxxxooxooooxxxo\noxxooxxooxoxooxxxoxxxooooxooxxxooxxxoooooxxoxoxxoox-xooxxoooxxxoooooxoxxxooooxoxooxxoooxooooxxxxoxox\nxxoooxoxxxoxxoooxooxoxoxooxxxooxoxoxxxoxoxxxxxoxooxo-xooxoxooooxoxxooxxoxoxxoxoxoxooxoxoxxooxoxooooo\nxoxxoxxoxoooooxxxoxoxxxxoxxooxooxxoooooxoxxoxxxooxxxo-xxoxxxxoooooxxooxxxxxoxxxoxxxxxxxooxxxoxoxoxox\nxoxoxooxxxoxxxxooxoooooooxxooxxxoxxxooxooxoxooxxxooxxo-xoxoxoxxooxxxooxooxoxoxxxooxxoooxoxxoooxxxxxx\nxxooxooxoooxxxxoooxooxoxoxoxooxxoxooxooxxxoooxoxoxooxoo-xoxooxooxxxxxooxxooxoxooxoxooxxxoxoxxxxxoxxo\noooxxoxxoxoxoooxxxoxoxxxxoxxxxoxxoooxoxoxxoooxxoooxooxxo-oooxxoxooxxxoxxxoxooxxooxoxoooxoxxxoxoooxxo\nooxxxxoxoxoxoxoxooooxxooxxxoxoxxxxxoxxxxxoxxxxxxoooxxooxx-oooxxoxoxxoxoxxoxooxoxxooxxoxxooxxoxooxxoo\nxxooxxooxooxooooooxxooxxxoxoxooxoxxoooooxxxxxxxoooxxooxoxx-xxxooxoxoxooooxxoxoxoxoxxxxoooxxxxxooxxox\nxxoxoooooxooooooxoooxoooxxoooxoxxxooxxxxoooxoxooxoxxxooxxxo-oxxxxooxxooooxoxxoxxoxxooxoxoxoxoooxxxxo\nxooooooxoxoxooxxxoxoxoxoxxoxoxxxoxxxxxxxxxooxoxxooooxoxxoxox-xxooxoxxoxooxxoxoxoxoooooxxoxoxoxoxooxx\nxoxxoxoooooxooxooxooxoxxxxoxxooooxxxooxoooooxxoooxooxxooooooo-oooxxxooooooxoooxxoxxoxxxoxooxxooxxoxx\nxoxxooxoxxoxxooooxoxooxxxxooxxxooooooooooxxoooxxoxooxxoxxoxoox-xxxxxooxoooxoxoooooxooooxxxooooxxooxx\nxoooooxoxoxxxoooxxxoxoooxooxooxoxxooxoxooxooxxxoxxxxoxxxoxxoxxo-ooxxxxoooxoxxoxoxoxxoooooxxxoxoxoxox\nxxoxxoxoxxoooooxxxoooxooxxxxxoxooxoxoooxoxxxooxxoxoxxxxoxoooxxox-ooxooxoxoxxoxxxxxoxxoxxxxoooxoxxxxo\nooxxxxxxxxxooooxoxooxoxoooxxoooxxxxoooxoxxxxoxooxxxxoxooxxxxoooxx-oxxoooxoxoxooxxxoooxooooxxoxxooxxx\nxoooooxxoxoxoxxoooooxoxxoooxxoxoxxxxooooxxoxoooooooxoooooooxxoooxx-ooxxxxoxxxoxoxxxoxooxxooxoxooooxx\nooxxooooooxooxoxoooooxxooxxoxxxxoxoxxxxxxxoxxxooxxoxxoooooxooooooox-ooxoooxxoooxoooooxxxxxxxoxxxxoox\noxoxoxxooxoxxoxxoxxoxooxoxxxooxoxxxoooxxxxoxoxxoxxooxxxooxoooxxoxoxx-oxxoxoxxoxoooxxoxoxxxxxxoxooooo\nooxoooxxooxoxoooooooxxxxxxxoooxoxxoxoxxxoooxxoxxoxoxoxxxxoxxxxxoxxoxx-xxooxxoxxoxxoxooxooxoxoooxxooo\nxoxoooxoxoxoxoooxxoxxxooxoxxooooxxooooxoxxooxxoooxoooooxoxxxoxoxoxoooo-xoxxxooxxxxxoxooxooxxxoxxooxo\nxxooxoxxoxoxxoxoooooxooxoxxxooxxoooooooxxxxxooxoxoxoxoxoooxxxxxxxxoxooo-xxxoxoooxoxxoxoxxooxooxxxoxx\noooxooxoxooxoxxxoxxooxoooxxooxxxxxoxoxxxxooooxxxooxoooxoooxxxxxxoooxxxxo-oxooxxoxxoxooxxooooxooxoooo\nooxoxooxxxooxxxoooxxoooooooxxxooxoxxxxxxxoxooxoxooxxxooxxxoooxxoxxxxoxoox-xxxxoxoxxxooooxxxoxoxooxoo\noxooxxxxxoxxxxxxooxxxooxxoxxxoooooxxxooxxxxoxoooxxoxooxxoooxoooxooooxooooo-xoooxxoxoxoxoxooxxoooooxx\noxooxoxoooxxoxoooxxxooxxxooxxooxoooooxoxxxxxooooxooxoxooxxxoxxxooxoooooxxoo-xxxoooooxoxoxoxoooxxooox\noxoxxxxxxoxxooxooxoxooxxoooooxxxxoxxoxxxoooxooxoxxoxxoxxxxoooxooxooxoxxoxoxo-xoooxoxoooxooooooxoxoxo\nxooxxoxxxooxoooxxoxooooooooooooxoxooxoxxoxoxoooxxxxoooooooxxxxxxoxxxxoxxooxoo-oooxxoxxxxoxxoxxoxooxx\nxxxxxoxxxxoxoxoxxxooxxoxxoooxxxoooxoooxxoooxooxxxooxxooxoxooooxooxoxoooxoxxoxx-xoooxxoooooooxxoooxxo\nxooxoxoooooxoxxoooooooxooxooooxoxoxxxxoxxoooooooxoxooxoxxoxoxoxxooxoxxoxxooxxxo-xoxxoxxoxoxxoxoxoooo\nxoxxxooxooxxxooxoxxooxxoxxxoxooxxxooxxxooxxxxoxxoooxxoxoxooxoxxooooxxooooxoxxxxo-oxooooxxoxoxxxoooox\noxoxxxoxxoxxooxxxxoxxooxoooooxxoxoooxoooxoooxoxoxxoxooxxoxxoxoxxoooxxooxooxxooxxx-xxoooooxooxxxxxoox\nxoxxxoooxooxxoxxoooxxoooxoooxxxxoxxxxoxoooooooooxoooxoooxxooxoooxxoxoxooxooxxoxooo-oxoxoxoooxxxxxxoo\nxooxxxxxxxoooxooooooooooxxoooxoxoxxoxxxxxoxoxoxoooxoxooxoooxxxxooxxxooxoooxxoxooxox-xxoxooooxxxxxoxx\noxxoxxxxxxooooxooxxxxxooxoxxxxooxxxxxxoxoooxxxoxxoxxooxxxooxxoxxoxoxxxoxxxooxooxxxoo-oxxoxxoooxoxxxo\nxxoooxxxxoxxoxoxoxoxoxxooxoxoxoxooxxooxoxxoxoxxooxoxxoxoxxooxoxxxoxooxxoxxxxxoxoxxxox-xxoxxoxoooxoxo\noxxoxoxxooxxoxoooxoxoxxxxxoxooxxoxooxooxxxooooooxooxooxoxoxxooxxoxxoxoxxoxooxoxoxxoxoo-xooxoxoxoxooo\noooxxoxxoxoxxxoxxxooooxxoxooxxoooxxoxooooxoooooxooooxxooooxooxoxoxoooxoooxxxooxxoxxoooo-oxoxxxoxxoox\nxoxoooxoxoxoxoxooxoooxooxoxxxoxooxxxooooooxxoooooxoxoxxxxxxxxooxoxoooxxoxoooxxxooxoxxxxx-oxxooxoxoox\nxoxxoooxoxxoooxoxxxxxxoooxoooxooxxxxxoooxooxxxxooxxxoooooxoooxoooxxoooxxxoxxxoxxxoxxooxox-xxxooxxxxx\nxoooxoxxoooooxoxoxoxoooxoxxxxoxxooxxxxoooxoxxxxoxoxxxooxoooxxxxoxoxooxoxxoxoxoxooxxxoooxoo-oxxoxxooo\noxoxxxoxooxoxoxxxxoooxooxooooxooxxxoxxooxoxooooooxoxxoxoooooooxoxoooooooxxoxxxxoxxxxxxxooox-oxxxoooo\noooxxoxooooxxxooooxoxoxxxoxoxoooxoxooxxooxxooxooxoxooxxoxxoxxoxxxxxxoxoxoooxxooxooooxoooxoox-xxxxoxo\noooxooxoooxoxooxxoxoxxxoxooooxxooxxooxxxoxxxoxxxxoxoxoxooooxoxxoooooxxxxxxxxxoooooooxxxoxxooo-xooxxx\nxxxxoxoxooxooxoxooooooxoxooxoooxxoooxxxooxxoooxooxxooxooxxxxxxoxxoxooxooxoxooxxxoooooxoxoxxooo-xoxoo\noxooxxoxoxxoxxoxxoxxoxxooxooxoooxoxxooxxoxxooxxoooxoxoooxxxooooooxxoxooooxxoxoxoxoooxxxoxooooxo-ooxx\nooxxxooxooooxxoxooxxxxoxxooooxoxoxoxxoxxxooxoooooxoxxxoxxoooxoxxoxxoxoxoxxxxoxxxxooooooooooxoxxx-xox\nxxxxxxooxxoxxoxooxxxxxoooooxxoxxxoxoxxxooxooxooxoxooxoooooooxxxoooxxxxxxxoxxxxoxxxoxoxxxxoxxxooxo-oo\nooxooooxxooooooxxooxoxoxxxxooxxxxxoooooxxooooxxxoxoxxxoooxxooooxoooxxxooxxoxoooxxxxoooxxxoxxooxoxx-x\nxxoxoxoxxoxoooxoxxxoooxoooooxxxoxxooxoxxxooxooxoooxoxooxxxoxooooxoooxxxoxxooxoxxooxoxxxoooxxxoxooxo-\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '26 34 62 88 67 76 80 83 39 63 92 95 29 96 31 33 37 52 60 68 71 4 12 30 41 42 73 75 77 78 79 87 93 99 100 1 5 8 15 18 21 22 25 36 53 89 7 24 45 56 82 84 91 94 97 2 9 14 23 40 47 57 64 46 59 72 81 20 27 28 32 55 61 66 70 74 3 13 16 38 90 35 43 50 51 69 11 19 44 65 6 48 58 86 98 17 10 54 49 85\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_3():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='100\n-xxxoooxxoooooooxoxooxooooxooooooooxoooooooooooooooxxooxoooxooooxoooooooxoxoxooooooxooooooxooxoooooo\no-xoxooxoxoooooooxxooxooooxoooooooooxooxxoxoxxooooooooooxoooooooxoxooooxoxooooooooooxooxooooooooooox\noo-ooxoxoooooxoxooooooooooooxoooooooxoxoooooooooxoxoxoxooxoooxooooooxxooxooxooxoxoxxoooooxxxoooooooo\noxx-xooooooxxxxoxoxooooooooooooooooxoxoxxoxoooxooooooxxxoxooooxoxoxooxooooooooooxooxoooxxxooxooooooo\nxoxo-oooxooxooooooooooooooooooxxooooooxxooooooxooooooxxoooxxoooooxxoooxoxxooxooooooooooooxooxooooooo\nxxoxx-ooooxoxoxooooxooxoooxoxoxoooooxooxxxooxooxooooooxooooooooooooooxooooxxoooxxoxoxoxooooxoooxxoxx\nxxxxxx-xoooxxxxoooxxoxxoooxoxoooooooooooooooooooxxooooxxoooooooxooooooxooooooooooooxoxooooooxooxooox\noooxxxo-ooooxooooooxoooxoxoooooooooxooxooooooxoxxxooooooooooxooooxxoooooooxoxxxooooxoooxooxooooooooo\noxxxoxxx-xxxooxoooxxxoooooooxooxoooxxxooooxoooxxxooxooooxoooooxoooooxxoooxoooooooxooxoxoxxxooooooxoo\nxoxxxxxxo-oxoooxooooxooooooooxoxoooooxoooooooooxooxoooxooooxoxxxoxoooooooxoxoooxoooooooooooooxxoxoox\nxxxxxoxxox-xooxxooooxxoooxoxoooooxoooooooxooooxoxxoxxxxxoooxoooxooooooooxoxooooooxooxooxooooooxoxxoo\nxxxooxoxooo-ooooooooooooooxoooooooxooooooxxooooooooxooooxoooooxoooooooxxoxoooooooooxxoxoooooooooxoox\nxxxoxoooxxxx-xoxooooxooxoxoxoooxxxxxxooooooooooxoooooxooxooxxooxxooxooxooxoooooooooooooooxooxoxooooo\nxxooxxoxxxxxo-xooooxoooooooooooooooxoooooxoooooooooooxooxooxxooooooxoxxooooxooxoooxooooxxxoxxxooxoxo\nxxxoxooxoxoxxo-ooooooooooxooxxxoooooxoxoooxooxoooxooooooxoooooxxoxoxooooxoooxoxxxooooxoxooooooxoooox\nxxoxxxxxxooxoxx-oooooooxxooxooooooooooooooooooooxxooooooxooxooxoxxoooxooooxooxoxoooooxooooxooxooooox\noxxoxxxxxxxxxxxx-xoxoxooooooxoxooxooooxoooxxooxoooooooxooooxoxoooxooooxoooxoxxoooxooooxoxoxoooxxxoxo\nxoxxxxxxxxxxxxxxo-ooooxoooooooooxoxooxxxoxooxoxooooooooxxooxooooxoooooooooooooooooxoooooooooxoooxoxo\nooxoxxoxoxxxxxxxxx-oooooooooooxxxoxxoxooooooooooxoooxooxoxooooxooxoooooooooooxooxoxoxoooxooxooxoxooo\nxxxxxooooxxxxoxxoxx-ooooxxooxooooooooooxxoxooooooooooxxooxoxoxxoooooooxoooooxxxooooooooxoooxooooooxx\nxxxxxxxxoooxoxxxxxxx-ooooooooxxoxxooooooxooooxxooxooxoxoooooxxooooooooooooooxooooxxoooxooxoooooooxox\nooxxxxoxxxoxxxxxoxxxx-xooooooooooooooxooxooxooxooooooxoooooooxxooooooxoooxoxoooooooooxoooxoxoooxooox\nxxxxxooxxxxxxxxxxoxxxo-ooooooooooxooxooooxooooxoooooxxooooxoooooxoooooxoooxooxxxooxoxooooxxxoooooooo\nxxxxxxxoxxxxoxxoxxxxxxx-oooxoooooxoxooooxxooxxxoooooooxxxxoxooooxooooxooooxooooxxxoxxooxooxooooxoooo\nxxxxxxxxxxxxxxxoxxxoxxxx-ooxxoooxxooooxooooooxooooooxxoooooooooxooooxoooooxooooooxoooooooooxxooxoooo\nxxxxxxxoxxoxoxoxxxxoxxxxx-xxooooxooooooooxxooooooooooxooooooooooooooooxoooxxoxxxxoooooooooxoooxoooox\nooxxxooxxxxoxxxxxxxxxxxxxo-ooooooooooxooooxxoxooxxxxooooxxoxoxoooxxoooooxxoooooxoooooxooxxoooooxooox\nxxxxxxxxxxoxoxxoxxxxxxxooox-ooxxooooxoxxoooxooooxooxoxoxxxoooooooooxxxoooooooxoxoooooxxoooooxoooxxoo\nxxoxxooxoxxxxxoxoxxoxxxxoxxx-xooooxoxoxooooooxoxxooxoooxoooxoooooxoxxooooooxoxxxxooooooooooooxxooooo\nxxxxxxxxxoxxxxoxxxxxoxxxxxxxo-oxoooooooxxooooooxooooxooooxooooxooooooooooxxoxxxoxoooooooooxxooooxooo\nxxxxooxxxxxxxxoxoxoxoxxxxxxoxx-oooxooxoxoooxoxoooooooxoooxxoooooooooooxoooxxxooxooooooooooxooooxxooo\nxxxxoxxxooxxoxxxxxoxxxxxxxxoxox-oooooooooxooxoooooxxooooxoooooooooxoooooooooooxoooooxoooooooooooxooo\nxxxxxxxxxxxxoxxxxooxoxxxooxxxxxx-ooooooooooooooooxooxoooooooooooooooxoooxoxooxoooxxoxxooooooooooooox\nxxxxxxxxxxoxoxxxoxxxoxoooxxxxxxxx-xooxxoxxoxooooooooxooooooooxooooxoooxooooxoooooooooxxoxoooooooooox\nxxxxxxxxxxxooxxxxooxxxxxxxxxoxoxxo-ooooxxooxoxooooxxooxooxxoooxooxxoxooxoxoxooooooxoxooxxoooooxooxxo\noxxoxxxooxxxooxxxxoxxxxoxxxxxxxxxxx-oooooooooooxooxoooxooooxoxoxxooooooxxxxoooooxooooooxoxxoxooooxoo\nxooxxoxxoxxxoxoxxxxxxxoxxxxooxxxxxxx-oooooxxoooxoooxoooooooooxxxxoxooxooxoooooxoxoooooooooooxooooooo\nxxxoxxxxooxxxxxxxooxxoxxxxoxxxoxxoxxx-xooooooooooooxoooooxoooxooooooxooxooooooxoooooooxooxoooooxoooo\nxxoxoxxoxxxxxxoxooxxxxxxoxxooxxxxoxxxo-ooooooooxxxoooooxxoooooxoooooooxxooooooooxooooooxoooxoooooooo\nxoxoooxxxxxxxxxxxoxoxxxxxxxoxooxxxoxxxx-ooooooxxoxooxooxooxxoxoooooxoooooooooooxoxooooxoxoooxoooxoxo\nxoxoxoxxxxxxxxxxxxxoooxoxxxxxoxxxooxxxxx-xoxxooooxxoxoooxooooxxxoooooxooxoooooooxoxoooooooooxxoooooo\nxxxxxoxxxxooxoxxxoxxxxooxoxxxxxoxoxxxxxxo-oxxooooxoooooooooxoxxooxooooxooooooxooooxoooxxxooooooooooo\nxoxoxxxxoxxoxxoxoxxoxxxxxooxxxxxxxxxoxxxxx-oxooxxxxoxoooooooooooxxxooxoxxooxooooooooxoxxxooooxoooooo\nxxxxxxxxxxxxxxxxoxxxxoxxxxooxxoxxooxoxxxoox-oxoxoooxxxooxooooooxoooooxoxooooooooooooooooooooxoooxoox\nxoxxxoxxxxxxxxxxxoxxxxxoxxxxxxxoxxxxxxxxooox-xoxxxoxooxooxooooooooooxooxxoxxxoxooxxooxxoooxoooxoxooo\nxoxxxxxoxxxxxxoxxxxxoxxooxoxoxoxxxoxxxxxxxxoo-xoooxoooxoxoxoxooooooxoooooxoooxoooooxoxoooxooooxoxooo\nxxxooxxxoxoxxxxxooxxooooxxxxxxxxxxxxxxxoxxxxxo-xooooxoooooxoxxooxoooxxoooxoxoxoooxoxxooooooxoxooxooo\nxxxxxoxoooxxoxxxxxxxxxxxxxxxooxxxxxooxooxxoooxo-oooooxoooxooooooooooxooxoooxoooxoooxxoooooxooxoooooo\nxxoxxxoooxoxxxxoxxoxxxxxxxoooxxxxxxxxxoxxxoxoxxx-ooooooooooooooooooxoooooooooooooxooooooxooooxxooxoo\nxxxxxxooxxoxxxooxxxxoxxxxxoxxxxxoxxxxxoooooxoxxxx-oxoooxxxxoooxooooooooxxooxoooxxooooxooooooooooxooo\nxxoxxxxxxoxxxxxxxxxxxxxxxxoxxxxoxxooxxxxoxoxxoxxxx-oxxxoxxxoxoxooxxoxoxooxoxoxoxoxoooxooooooxxoooxxo\noxxxxxxxoxooxxxxxxxxxxxxxxoooxxoxxoxooxxxxxooxxxxox-ooooooxoooxxoooooooxxoxooxoxooxooooxoxooxooooxoo\noxoxxxxxxxoxxxxxxxoxoxoxoxxxxoxxooxxxxxooxooxxoxxxox-oooooooooooooooxooooxoooooooooxoooxooxooxoxoooo\nxxxooxxxxxoxooxxxxxoxooxooxoxxoxxxxxxxxxxxxoxxxoxxoxx-xxooooooxxooooxoooxoooxooooxxooooxxoxoooooooxo\nxxoooooxxooxxxxxoxxooxxoxxxxxxxxxxooxxxxxxxxooxxxxoxxo-xoxooxoooooooxoooooooooooxxooooxooooooxoxoxoo\noxxoxxoxxxoxxxxxxooxxxxoxxxooxxxxxxxxxooxxxxxxxxxoxxxoo-ooxoooooooooooooxxxxoooooooxxoooxooooooooooo\nxoxxxxxxoxxoooooxoxxxxxoxxooxxxoxxxxxxoxoxxoxoxxxooxxxxx-oxoooooxoxoxooooooooooooooxooooxoxoooxooxox\nxxooxxxxxxxxxxxxxxooxxxoxxooxooxxxoxxoxxxxxxoxxoxooxxxoxx-oooooooxoooxxoxooxoxooooooxxooooxooooxoooo\nxxxxoxxxxxxxxxxxxxxxxxoxxxxxxxoxxxoxxxxoxxxxxooxxoooxxxoox-oooxxxxoxoxoxoooooooooooxoxoxooxxooxooxoo\noxxxoxxxxooxooxoooxoxxxoxxoxoxxxxxxoxxxoxoxxxxxxxxxxxxxxxxx-xooxooxxooooxoxoxoxoxoooxoooooxooxooooox\nxxxxxxxoxxxxooxxxxxxoxxxxxxxxxxxxxxxxxxxxxxxxooxxxoxxxoxxxxo-oooooooooooooxoooooooooooooxoxooooooooo\nxxoxxxxxxoxxxxxxoxxoooxxxxoxxxxxxoxoooxoooxxxxoxxxxxxxxxxxxxx-xooooooxoooxooooxoooxooooooooooooxxooo\nxxxoxxxxooxoxxooxxooxoxxxxxxxoxxxxoxoxoxooxxxxxxxoooxoxxxxoxxo-oxxoooooooxxoxooxoooooooooooooxoooxoo\nxxxxxxoxxooxoxoxxxxxxxxxoxxxxxxxxxxooxxxoxxoxxxxxxxoxoxxxxooxxx-ooooxxxooooooxooooooxxxoooooooxoooxo\nooxoxxxxxxxxoxxoxoxxxxooxxxxxxxxxxxooxxxxxoxxxoxxxxxxxxxoxoxxxox-ooooxoxooooooooxooooooxxoxoooxooooo\nxxxxoxxoxoxxxxoooxoxxxxxxxoxoxxxxxoxxxxxxooxxxxxxxoxxxxxxooxxxoxx-oooooxooxxxoxoooooxoooxoooxoxxooxo\nxoxooxxoxxxxxxxxxxxxxxxxxxoxxxxoxooxoxxxxxoxxxxxxxoxxxxxoxxoxxxxxx-oxooooooxxoooxxoooxxoooxooxxoxoxx\nxxxxxxxxxxxxoooxxxxxxxxxxxxooxxxxxxxxxxoxxxxxoxxoxxxxxxxxxooxxxxxxx-ooxxooooooooooooxooxoooooxooxoox\nxxoxxxxxoxxxxxxxxxxxxxxxoxxooxxxoxoxxoxxxxxxoxooxxoxoooxoxxxxxxoxxox-oooooxoxoooooxxoxxoxooooooooxxx\nxxooxoxxoxxxxoxoxxxxxoxoxxxoxxxxxxxxoxxxoxooxxoxxxxxxxxxxooxxoxooxxxx-ooooooooxoooooooooxooooxoooooo\nxxxxoxoxxxxoooxxoxxoxxoxxoxxxxoxxoxxxxoxxoxxxxxxxxoxxxxxxoxxxxxoxxxoxx-oooooooooooooxooxooooxoxoooxo\nxoxxxxxxxxxoxxxxxxxxxxxxxxxxxxxxxxooxooxxxoooxxoxoxoxxxxxxoxxxxxooxoxxx-xoxoooooxxoxxxoooooooooxooxo\noxoxoxxxxxoxxxoxxxxxxxxxxxoxxxxxoxxooxxxoxoxoxxxxoxoxoxoxoxoxxxxxxxxxxxo-oxxxxoooooooxxoooxoooooooxo\nxoxxoxxxooxooxxxxxxxxoxxxxoxxoxxxxooxxxxxxxxxooxxxoxoxxoxxxxxooxxxxxxxxxx-xxoxooxooooooxoooooxoooxox\noxxxxoxoxxoxxxxooxxxxxooooxxxooxoxxoxxxxxxxxoxxxxxxoxxxoxxxooxoxxoxxoxxooo-xoooooooooxoooxooooooooox\nxxoxxoxxxoxxxoxxxxxxxoxxxoxxoxoxxooxxxxxxxoxoxooxooxxxxoxoxxxxxxxooxxxxxooo-ooooooooxooxoooxoxooxoxx\noxxxoxxoxxxxxxoxoxxooxxxxxxxxooxxxxxxxxxxxxxoxxxxxxxxoxxxxxoxxoxxooxoxxxoxxx-ooxoooooxxooooxoooooooo\nxxxxxxxoxxxxxxxooxooxxoxxoxoooxxoxxxxxxxxoxxxooxxxooxxxxxoxxxxxoxxxxxxxxooxxx-ooxxooxooooxooxxooooox\nxxoxxxxoxxxxxooxxxxoxxoxxoxxooxoxxxxooxxxxxxoxxxxxxxxxxxxxxoxoxxxoxxxoxxxxxxxx-oxoxooooooooooooxoooo\nxxxxxoxxxoxxxxooxxxxxxooxooooxoxxxxxxxxoxxxxxxxoxoooxxxxxxxxxxoxxxxxxxxxxxxxoxx-xoooxooxooooxoxoooxo\nxxooxoxxxxxxxxoxxxoxxxxoxoxxooxxxxxooxoxoxxxxxxxxoxxxxoxxxxoxxxxoxoxxxxoxoxxxooo-oooooooooooooooxxoo\nxxxxxxxxoxoxxxxxoxxxoxxooxxxxxxxoxxxxxxoxxxxoxoxoxoxxooxxxxxxxxxxxoxxxxoxxxxxoxxx-ooxooxoooxoxxoooox\nxxoxxoxxxxxxxoxxxooxoxoxxxxxxxxxoxoxxxxxooxxoxxxxxxoxoxxxxxxxoxxxxxxoxxxxxxxxxoxxx-ooxxooooxooooxooo\noxooxxooxxxoxxxxxxxxxxxoxxxxxxxxxxxxxxxxxxxxxoooxxxxoxxooxoxxxxxxxxxoxxoxxxxxxxxxxx-xooxooooxoxooooo\nxoxxxoxxoxooxxxxxxoxxxooxxxxxxxooxoxxxxxxxoxxxooxxxxxxxoxoxoxxxoxoxoxxooxxxoxoxoxoxo-oxoxxxooxoxoxoo\nxxxxxxoxxxxxxxooxxxxxoxxxxooxxxxooxxxxxxxxxxooxxxooxxxxxxooxxxxoxxoxoxxooxoxoxxxxxoxx-oxoxoxxooooooo\nxxxxxoxxoxxoxxxxoxxxoxxxxxxoxxxxxoxxxoxoxooxoxxxxxxxxxoxxxxxxxxoxxoxoxxxoxxxoxxxxxoxox-ooxoooxoxxxoo\nxoxoxxxoxxoxxooxxxxoxxxoxxxxxxxxxxooxxoxxooxxxxxxxxoooxxxxoxxxxxoxxoxxoxxoxoxxxoxoxoxox-ooooxoooooxo\nxxxoxxxxoxxxxoxxoxoxxxxxxxoxxxxxxooxxxxoxooxxxxxoxxxxoxooxxxoxxxooxxooxxxxxxxxxxxxxxoxxx-xoxooooooxo\nxxoooxxxoxxxooxxxxxxoooxxxoxxxxxxxxoxoxxxxxxxoxxxxxoxxxxxxxxxxxxxxxxxxxxxxoxxoxxxxxxoooxo-oxxooxoooo\noxoxxxxooxxxxxxooxxxxxooxoxxxooxxxxoxxxxxxxxoxxoxxxxooxxoooooxxxoxoxxxxxoxxxxxxxxxxxoxxxxx-ooooooooo\nxxoxxoxxxxxxxoxxxxooxooxoxxxxoxxxxxxxxoxxxxxxxoxxxxxxxxxxxoxxxxxxxxxxxxxxxxooxxxxooxxoxxoox-xooooooo\nxxxooxoxxxxxooxxxoxxxxxxoxxoxxxxxxxooxxooxxoxxxxxxooxxxxxxxxxxxxxoxxxxoxxxxxxoxoxxxoxoxoxoxo-oxoooox\noxxxxxxxxoxxxoxoxxxxxxxxxxxxoxxxxxxxxxxxoxoxxxoooxoxoxoxxxxoxxoxxxooxoxxxoxoxoxxxoxxoxoxxxxxx-ooxooo\nxxxxxxxxxooxoxoxoxoxxxxxxoxxoxxxxxoxxxxxxxxxooxxoxxxxxxxoxoxxxxooooxxxoxxxxxxxxoxoxoxxxxxxxxox-oooxo\nxxxxxooxxxxxxxxxoxxxxoxooxoxxxoxxxxxxoxxxxxxxxxxxxxxoxoxxoxxxoxxxoxxxxxoxxxxxxoxxxxxoxoxxoxxxxx-oooo\nxxxxxoxxxoooxoxxoooxxxxxxxxoxoooxxxxxxxoxxxooooxxoxxxxxxxxxxxoxxxxooxxxxxxxoxxxxoxoxxxoxxxxxxoxx-ooo\nxxxxxxxxoxoxxxxxxxxxoxxxxxxoxxxxxxooxxxxxxxxxxxxoxooxxoxoxoxxxoxxxxxoxxxxoxxxxxxoxxxoxoxxxxxxxxxx-oo\nxxxxxoxxxxxxxoxxooxoxxxxxxxxxxxxxxoxxxxoxxxxxxxxxxoxxoxxxxxxxxxoxooxoxoooxxoxxxoxxxxxxxooxxxxxoxxx-o\nxoxxxooxxoxoxxooxxxoooxxxooxxxxxooxxxxxxxxxoxxxxxxxxxxxxoxxoxxxxxxoooxxxxoooxoxxxoxxxxxxxxxxoxxxxxx-\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '12 1 5 2 8 3 7 10 4 16 14 15 6 18 22 13 19 20 32 9 11 21 23 26 25 33 38 39 31 17 29 30 34 37 49 27 48 28 42 53 24 36 40 44 41 46 55 50 57 56 63 35 43 52 47 54 58 62 70 75 61 60 65 45 64 71 76 81 59 66 69 73 51 74 77 88 68 72 78 79 85 91 67 80 86 83 82 89 93 94 97 84 87 90 95 92 100 96 99 98\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_4():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='100\n-xxxxxxxxoxoxoxxxxxxxxxxooxxoxxxxxxxxxxxoxxoxxxxxoxxxxxxoxxxxxxoxxxxxoxxxxxxoooxoxooxxxxoxxoxoxoxxoo\no-xxxxxxooxoxxxxxxxxoxxxxxxxxxxxooxxxoxxooxxooxxxxxxxxoxxxoxxxxxoxxxxoxxoxoxxxxxooxoxxxoxxxxoxxxxxxx\noo-oxxxxxxxxxxxxxxxxxxxoooxxxxxxxxoxxxooxxxxxxxoxxxxoxxxoooxxxxxxxxxxxxxxxxxxooxoxxxxxxxxoxxoxxxooxo\noox-xxxxxxoxxxoxxoxxxxxxoxxxoxxxxoxxxxxxxxxxxxoxxxxxxoxxoxxxxxxxxxxxxoxoxxxoxxxoxxoxxxooxxxxoxxoxxox\noooo-xxxxxxxxoxxxxxoxxxxxxoooooxxxxxoooooxxxxxxxxoxxoooxxxoxxxxoxxoxxoxxoxxxxxxxxxooxoxoooxxooooxxox\nooooo-oxxxooxxxxxxxxxoxxoxxxxoxooxxxxxxxoxoxxxoxxxxxxxxoxxxxoxxxoooxxxxxxxxxxxxoxooxooxoxxoxxxxxxoxo\nooooox-oooxxoooxxxxoxxoxoxxxoxoxoxxxxxxxxxxxxoxoxxxxxxxxxxoxxxxxxxoxoxxxxooxxxxxxxxxxxxoxxoxxxooxxxx\noooooox-oxxxxxoxxoxxxxxxxxoxxxxxxoxxxxxxxxooxxxoxxxxooxxxoxxoxxxoxoxxxxxxoxxxxxxoxxoxxooxxxxxoxxoooo\noxooooxx-ooxxxxooxoxoxxxxxxxooxxxxxxxxxxoxoxxxxxooxxoxxooxxxxoxxxxoxooxoxxxxoxxooxxxooxxoxxxxoxxoxxo\nxxooooxox-xoooxxxooxxxxxxoxxxoooxxoxxxxxxxxxxxxxoxoxxxxxxxxxxxoxoxxxxoxxxxxoxoxoxxxxxxxoxoxxooxxxxxx\noooxoxooxo-ooooxxxoxxoxxxoxxxoooooxxxoxxoxoxoxxxxoxxoxxxxxxxxxxxooxxxxoxxoxoxxxxxxxxxxooxxoxoooxxxxo\nxxoooxoooxx-xxoxxxxxxxoxxxxoxxxxoxxxoxoxxxoxxxxxxxoxxxxxxxxxxoxoxxxxxxxxxoxoxxxxooxxxxxxxxxxoxooxxox\nooooooxooxxo-xxxooxoxxxxxooxoxooxxxooooxoxxxxxxxxoxxxxxoxxxooxxxxxxxooxxxxxxxoxoxoxxoxxxxoxxxxoxxxox\nxoooxoxooxxoo-xxxxxoxxxxxxxxxxxoxxxoxxxxoxxxoxxxxxxxxxxxxxxoxxxxxxoxoxxxoooooxxxxooxxxxxoxxxxxxooxxo\noooxooxxooxxoo-oxoxxoxxxxxxxoxxxxxxxooxxxxxxooxxooxxooxxxxxxxoxxoxxxxxxxxxxxoxoxxoxxxxxxxxxxxxxxxoxo\nooooooooxooooox-oxoxxxxxxxxoxxxoxxxxxxxxxxxxxxoxxxxxxxoxxxxxxoooxxxxxxoxxxxxxoxooooxxoxoxoxxxxxxxxox\nooooooooxoooxoox-xooxxxoxoxxxxxoxxxxxxoxxoxoxxxoxxoxxxxxoxxxxxooxoxxxxxooxxxxxxxxooxxoxxoxoxxxoxxxox\noooxoooxoxooxoxoo-xxxoxxxxoxxoxoxxxxxxoxxxxxoxxxxoxxoxxoxxxxxoxooxoxoxxxxxxxoxxxoxxxxxoxoxoxxxxxxxox\nooooooooxxxooooxxo-xxxxxxxoxooxxxxxxxoxxxxxxoxxxooxxxxxxoxooooxxxoxxxxoxxxxoooxxoxxooooxxxxxoooxoooo\nooooxoxoooooxxooxoo-xxxoxxoxxxoxxxxxxoxoxxxxxxoxxooxxxxxxxxxxxxxxxoooxoxxxxxoxxxxxoxxoxoxxxoxxxxxxox\noxooooooxoooooxooooo-xxxoxxxxxxxxxxxxxoxxxxxxxooxxxoxoxoooxxxxxxxxxxxoxoxxoxoxxxxxxxxxoxoxxoxxxxxoox\noooooxooooxooooooxooo-xxxxxoxxxoxxxxoxoxoxxoxxxoxxxxooxooxoxxoxxooxxxxxxoxxxxxxxoxxxxxxxxxxxxooxoxxx\nooooooxooooxoooooooooo-xxxxxxxoxxxoxxxxxxxoxxxxxxxxxxxoxxxxxxooxxooxoxxxoxxxoxxooxxxxxxxxxxxxoxxxxox\nooxoooooooooooooxooxooo-oxxoxxxoxxxxoxxxxxxxxxxxooxxxxxxooxoxxxxxxoxxxxoxxxxxoxxxxxoxxxoxxxooxxxooox\nxoxxoxxoooooooooooooxoox-oxxxxxxoxxoxxooxxxxxxxxxxoxoxxxxoxxoxoxoxxoxoxxxxooxxxxoxoxoxxxxxxxxxxooxxx\nxoxooooooxxoxoooxooooooox-xxxxxxxxxoxxxooxxoxxoxoxxxoxxxxxxxxxxxxoxxxxxxxxxxxxxxxxxxxxxxxxxoooxoxxxo\nooooxooxooooxooooxxxoooooo-oxxxoxxxoxxoxxxoxxxoxxxxxooxxooxxoxxxxoxxxxxooxoxxxxxoxxxoxoxoxoxxxoxxoxx\nooooxooooooxoooxoooooxoxoox-xoxxxxxoxxoxxxxoxxxxxxoxxoxxxxoxoxxoxxooxxxxoxooxxxooxxxxxoxxxxxooxxxxox\nxooxxoxoxoooxoxoooxooooooooo-xoxoxxxxxxxxoooxxxxxxoxxxxxxxxxxxxxxoxoxxoxxxxooxooxoxxxxxxoxxooxxxxoxx\nooooxxooxxxooooooxxooooooooxo-xxxxoooxxoxxxxxxoxooxooxxxxxoxxxxxxxxxxxxoxxxxxoxxxxxoxoxxxxoooxoxxxxo\nooooxoxooxxoxooooooxooxoooooxo-xxxxxxxxoxooxxxxxxoooxxooxxxxxoxxoxoxxoxxxxoxoxoxxxxxxxxoxxxoxoxxxxox\noooooxoooxxoxxoxxxoooxoxooxoooo-xxoxxxoxxxoxxxoxxxxxxxxxxxxxxxxoxxxoxxxxxxxxxxxoxxxxxooxxxoxxxoxoxxo\noxoooxxoooxxooooooooooooxoooxooo-xooooxoooxxxxxoxxxxoxoxxxxoxxxoxoooxxoxxoxxxxxxoxooxxxoxxxxoxxxxxxx\noxoxoooxooxoooooooooooooooooooooo-oxxoxxxxoxoxoxxxxoxxxxoxxxxxxxxooxxxxxoxxoxxxoxxxoooxoxxxoxooxxooo\nooxooooooxooooooooooooxooooooxoxxx-oxxxxxxxxxxoxxxoxooxxoxxxxoxoxxoxxxxxxxoxxxoxxxxxxxxxxxxxxxxooxoo\nooooooooooooxxooooooooooxxxxoxooxox-xoxxxxxxxoxxxxxxooxxxxxoxxxoxxxxoxxxxxxxooxxxxxxooxxxxxxxoxxoxxx\nooooxooooooxxoxooooooxoxoooooxooxooo-xxxoxxxxxoxooooxxxxoxxxoxxxoxoxoxxxxxxxoxxoxxxxxoxoxxoxxxxxxxxx\noxooxoooooxoxoxoooxxooooooooooooxxoxo-xxxxxxxxxoxxxxxxoxoxxxxoxoxoxxxxxxoxxxxxoxxxxoxoxooxxoxxoxoxxo\nooxoxooooooxxoooxxooxxooxoxxoooxoooooo-xxxxxoxooxxxxxxxxxxxoxxxxxxxxxxxoxxxxxxoxxxoxxxxxxxxxxoxxooxx\nooxoxooooooooooooooxooooxxoooxxoxoooooo-xxxoxxxxoxoxxxxxxxxxoxxooxoxxxooxoxoxoxxxxxxxoxoxoxoxooxxxxo\nxxooxxooxoxoxxoooooooxoooxooooooxoooxooo-xxooxxoxxxxxxxxxxoxxxoxoxxxxxxxxxxxxoxoxxoxxxxxxoxxxxoxoxxo\noxooooooooooooooxoooooooooooxoxoxoooooooo-xxxxxxooxxoxxoxxoxoxoxxoxoxxxxxxoxoxxxxoxxxoxxoxoxxxxxxoxx\noooooxoxxoxxooooooooooxoooxoxoxxoxoooooooo-xxxoxoxoxxoxxxoxooxxoooxoxxxoxoxxxxxxoxxxxxxoooxxxxxxxxox\nxooooooxooooooooxooooxoooxoxxooooooooooxxoo-oxxoxxxxxxxxxoxoooxoxxxxxoxoxxxxxxxxxxxxoxxooooxxoxxoxxx\noxooooooooxooxxooxxooooooooooooooxooooxoxoox-xxxoxxxoxxoxxxoxoxxxoxxxooxxxoxoxxoxxxoxoxxoxxooxxooxxx\noxooooxoooooooxooooooooooooooooooooxooooooooo-oxooxxxxxxxoooxxoxxxxxxxxoxxxoxxxxxoxxxxxxxxxxxxxxxxxx\noooxoxoooooooooxoooxxooooxxooxoxoxxoxoxoooxoox-xxxoxxxxxxxxoxxoxxxxooooxxxxxxxxoxxxxxxoxxxxxoxooxxxx\nooxoooxxooooooooxoooxxooooooooooxooooxxoxooxooo-oxxxxxxxxoxxxxoxxoxxxxxxoxoxoxxxxxoooooxxxxoxoxxxoxx\nooooooooxxooooxoooxooooxoxoooxooooooxooxoxxoxxox-ooxoxxxxxoxxoxooxxxxxoxxxxoxxxxxxxxxooxooxoxooxxxxx\nxoooxoooxoxoxoxooxxxoooxoooooxxoooooxooooxoooxoox-xxoxxxxxxxxoooxxxooxoxxxxxxoxxoxxooxxxxxxxxxoxxxxx\noooooooooxoxooooxooxooooxooxxoxoooxoxooxooxoooxoxo-oxxxxxxxoxoxxxxooooxxxxooooxxxxxxxxxxxxxooxoxoxxx\nooooooooooooooooooooxooooooooxxooxooxooooooooooooox-xoxxxoxoxxxxoxxxxxxoxxooxxxxxxxoxxoooxxooxxxoxxx\nooxoxooxxoxoooxooxoooxooxxxooxooxoxxoooooxooxoooxxoo-xooxxxxxxxoxxxxxxxoxoxxxoxxoxoxxxoxxooxxxoxxoxx\noooxxooxooooooxoooooxxooooxxooooooxxooooooxooooooooxo-xoxxxxooxxxxoxxoxoxxxxxxxxxoxxoxoxoxxxoxxoxxox\noxooxooooooooooxooooooxoooooooxoxooooxooooooooooooooxo-xxxxxxxxoxooooxxxoxxxxxxxxxoxxxxxxoxooxxxxoxo\noooooxooxoooxooooxooxxooooooooxooooooooooxooxoooooooxxo-xxoooxxoxxxxxxxoxxoxxxxxxxxxxoxoxxxxxxxxoxxx\nxoxxooooxoooooooxoxoxxoxooxooooooxxoxxoooooooooooooooooo-oxoxxxxoxxxxxooooxxoxoxxxxxxxxxooxxxxxxxxxx\nooxooooxooooooooooooxooxxoxoooooooooooooooxxoxoxoooxoooox-xxxxxxoxxooxoxxxxoxxoxxoxoxxxxxxoooxoxxxox\noxxoxoxoooooooooooxooxoooooxoxooooooooooxxoooxooxooooooxoo-xxxxxxxxxxxoxxxxxoxxoxxoxxxoxxxxxxxxxxxox\nooooooooooooxxooooxooooxooooooooxooxooxoooxxxxxoooxxoooxxoo-xxoxxoxooxxxxoxxxxxxxxxoxxxxoxoxxoxxxxxx\noooooxoxooooxoooooxoooooxoxxooooooooxooxoxxxoooooooooxoxoooo-xxxxxooxoxxoxooxxxxxooxxoxoxoxxxoxxxxoo\nooooooooxooxooxxoxxooxxoooooooxoooxooxoooooxxoooxxxooxooooooo-oxooxxxxxxxoxoxoxoxxxxoxxxoxxxxxoxxxox\noooooooooxoooooxxoooooxoxoooooooooooooooxxoooxxxoxoooooooooxox-xoxxxooxxxxoxoxoxoxooxxxxxxoxxoxxxxox\nxoooxooooooxoooxxxoooooooooxoooxxoxxoxoxooxxooooxxooxoxxooooooo-xxxxoxxoxxxxoxxoooxxxxxoxoxxxxxoxoxx\noxoooxoxoxxoooxooxoooxooxoooooxoooooxooxxoxoooooxooxooooxxoooxxo-xxxxxxooxxxxxxxooxxoxxoxxoxxxxooxox\noooooxooooxoooooxoxooxxooxxoxoooxxoooxoooxxoxooxooooooxooooxoxooo-oxooxxoxxxxxoxooxoxxxxxxxxxxxxxooo\nooooxxxxxooooxoooxoxooxxoooxooxoxxxoxooxooooooooooxooxxoooooxoooox-xxxxoxxxxxoxoxxoxxxxxxoxxoxxxxooo\noooooooooooooooooooxooooxooxxooxxooooooooxxoooxooxxoooxooxoxxoooooo-oxxooxxoxxxoxxxoxxxxxxooxxooxxoo\nooooooxoxoooxxoooxoxooxooooooooooooxxoooooooooxooxxoooxooxoxooxxoxox-oxxxxxoxoooxxxxoxxxxxooxoxxxoxx\nxxoxxoooxxooxoooooooxoooxoooooxooooooooooooxxoxoooxooxooooooxoxooxoox-oxxxxxxxooxxooxxooxxxxxxxoxxox\nooooooooooxooooxooxxooooooooxoooxooooooxooooxoxoxxooooooxxxoooooooooox-xxxoxxxxxxxoxxxoxxxxxoxxxoxxx\noooxooooxoooooooxoooxooxooxooxooooooooxxooxxoxoooooxxxoxxooooooxxoxxooo-xxxoxxxxoxxxxxxxxxoxxooxxxxo\noxooxooooooooxooxooooxxoooxxoooooxoooxoooooooooxooooooxoxoooxoooxxoxoooo-xxooxxoxxxoxoxxoooxooxxxxxx\nooooooxxooxxoxooooooooooooooooooxooooooxooxoooooooooxoooxooxoxooooooooooo-xxxxxxxoxxoxoxxxxoxxooxxxo\noxooooxooooooxooooooxoooxoxxooxoooxooooooxooxooxooxxoooxooooxoxoooooooxooo-xxoxxoxxoxoxoxxxxxxxxxxxx\noooxoooooxxxoxooooxoooooxooxxooooxoooooxoooooxooxoxxoooooxooxxoooooxxooxxoo-xoxxooxxxoxxoxoxxxoxxoxx\nxoooooooxooooxxooxxxxoxoooooxoxooooxxooooxooxooxooxoooooxoxoooxxooooooooxooo-xxxxxxxxxxxxxoooxoxoxxx\nxoxooooooxooxooxooxooooxoooooxoooooxoooxxooooooooxxoxooooooooxooooxoxoooooxxo-ooxxxxxxxxxoxoxxxxoxxx\nxoxoooooooooooxoooooooooooooxoxoooxooxxoooooooooooooooooxxooooxooxooxxooooooox-ooxxxxxooxoxxoxxxxxxx\noooxoxooxxooxooxooooooxooooxxooxoxooxoooxoooxoxoooooooooooxooxoxooxxxxooxooooxx-oxxxoxxxoxoxxxxxxxxx\nxxxooooxxooxoooxoxxooxxoxoxxooooxoooooooooxooooooxooxoooooooooxxxxoooooxooxxooxx-xoxoxxxoxxxxxooxxxx\noxoooxoooooxxxxxxoooooooooooxooooooooooooxoooxoooooooxoooxooxooxxxoooooooxoxooooo-xxoxxxooxoooxxxxxo\nxooxxxoooooooxoxxooxooooxoooooooxoooooxoxooooooxooooxoxoooxoxoxoooxooxxoooooooooxo-oxoxooxxoxxoxxxxx\nxxooxooxooooooooooxooooxoooooxooxxoooxooooooxooxoxoxoooooxoxooxooxoxoxooxoxooooooox-xxxxxxxoxoxxooxx\noooooxooxoooxoooooxoooooxoxooooooxoxoooooooxoooxoxoooxoooooooxooxoooxooooxoooooxxxoo-xxxxxxxooxxxxxx\nooooxxooxooooooxxoxxoooooooooxoxoxoxxxoxoxooxooxxooooooxooooxoooooooooooxoxxooooooxoo-oooooxxxxxxxxo\noooxoooxooxooooooxxoxoooooxxoooxooooooooooooooxxxooxxxooooxooooooooooxxooxooooxoooooox-oxxxxooxoxxoo\noxoxxxxxoxxooooxoooxoooxooooooxoxxooxxoxooxxoooooooxoooxooooxooxxooooxooooxoooxoooxooxx-ooxxooxoxxxx\nxoooxoooxooooxooxxooxoooooxoxooooooooxoooxxxxoooxooxoxooxooxoxooooooooooxooxoooxxxxooxox-xxxxxoxoxxx\nooxoxooooxooxooxoooooooooooooooooooooooxxoxxooooxoooxoxoxoooxooxooxoooooxooooxxooxoooxoxo-oxoxxxoxxo\noooooxxoooxoooooxxooooooooxooxoxooooxooooxoxooooooooxooooxoxooxoxooxxooxxooxxooxoooooxooox-xxoooxoxx\nxooooooooooooooooooxxooxoxooxxxooxoooxoxooooxooxxoxxooxooxoooooooooxxooooxooxxoooxxxooooooo-xxxxxoxo\noxxxxooooxxxooooooxooooxoxoxxxooxoooooooooooxoxoooxxoxxooxooooooooxoooxoxoooxoxooxooxoxxoxoo-oxoxxxx\nxoooxooxxxxoooooooxooxxooxoxooxooxoxooxxoooxoooxxooooooooooxxoxoooooxooxxooooooooxoxxoxxooxox-ooxoxo\nooooxoxoooxxxoooxoxooxooooxooxoxoxoooxoxxoooooxoxxxoxooooxoooxoooooxoooxoxoxxoooxoxoooooxoxoox-xxoxx\nxooxxoxooooxoxooooooooooxxooooooooxoooooooooxoxooooooxoooooooooxxooxoxoooxooooooxoooooxxooxoxxo-oxxx\nooxooooxxooooxooooxooxoxxooooooxooxxoxxoxooxxoooooxxoooxooooooooxoooooxoooooxxoooooxooooxxooooox-xxx\nooxooxoxooooooxoooxoxooxooxoxooooxooooxooxoooooxooooxoxooooooooxoxxoxooooooxoooooooxooooooxxoxxoo-xx\nxooxxooxoooxxooxxxxxxoxxoooxooxooxxoooooooxooooooooooxoooxxoxxxoxxxxoxooooooooooooooooxooooooooooo-o\nxoxooxoxxoxooxxoooxooooooxoooxoxoxxooxoxxoooooooooooooxoooooxooooxxxoooxoxoooooooxoooxxooxoxoxoooox-\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '96 98 87 90 79 82 91 97 74 99 100 85 86 92 83 73 94 68 84 78 93 95 88 89 63 75 76 61 71 52 69 70 77 55 58 80 81 66 72 62 54 65 56 57 64 67 42 45 60 34 46 48 51 59 40 44 49 43 33 53 50 37 38 47 19 27 35 28 31 41 30 24 36 22 29 11 25 5 17 39 13 21 23 9 32 16 18 20 26 6 8 7 15 10 14 1 12 2 3 4\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )



from buggy import Solution


def test_case_0():
    sol = Solution()
    result = sol.powerfulIntegers(2, 3, 10)
    assert result == [2,3,4,5,7,9,10]


def test_case_1():
    sol = Solution()
    result = sol.powerfulIntegers(3, 5, 15)
    assert result == [2,4,6,8,10,14]



from functools import lru_cache

S_x = lambda: input()
N_x = lambda: int(input())
N_more = lambda: map(int, input().split())
A_L = lambda: list(map(int, input().split()))

N = N_x()


@lru_cache
def n_split(x):
    if x == 1:
        return 1
    else:
        if x % 2 == 0:
            return n_split(x // 2) + n_split(x // 2) + x
        else:
            return n_split(x // 2) + n_split(x // 2 + 1) + x


ans = n_split(N) + N
print(ans)



n = int(input())
s = input()
a = []
T = False
b = 1
for i in range(n - 1):
    if s[i] == ">":
        b += 1
    else:
        if b != 1:
            a.append(b)
            b = 1
if b != 1:
    a.append(b)
c = 0
for i in a:
    c += (n * (n - 1)) // 2
print(c)



from collections import Counter
from functools import reduce

N = int(input())


def prime_factorize(n):
    a = []
    while n % 2 == 0:
        a.append(2)
        n //= 2
    f = 3
    while f * f <= n:
        if n % f == 0:
            a.append(f)
            n //= f
        else:
            f += 2
    if n != 1:
        a.append(n)
    return a


cnt = 0
for AB in range(1, N // 2 + 1):
    CD = N - AB
    if AB == 1:
        cntAB = 1
    else:
        cntAB = reduce(lambda x, y: x * (y + 1), Counter(prime_factorize(AB)).values(), 1)
    if CD == 1:
        cntCD = 1
    else:
        cntCD = reduce(lambda x, y: x * (y + 1), Counter(prime_factorize(CD)).values(), 1)
    cnt += (cntAB * cntCD * 2) if AB != CD else (cntAB + cntCD)


print(cnt)



from typing import List, Optional, Tuple, Dict, Set
from collections import defaultdict, Counter, deque
import heapq
import math
import bisect
import itertools
import functools


class Solution:
    def longestCycle(self, edges: List[int]) -> int:
        v = [0] * len(edges)
        ans = -1
        for i in range(len(edges)):
            t = 1
            c = i
            while c >= 0:
                if v[c] != 0:
                    if v[c][0] == i:
                        ans = max(ans, t - v[c][1])
                    break
                else:
                    v[c] = [i, t]
                    t += 1
                    c = edges[c] - 1
        return ans



N = int(input())

W, X = [], []

for i in range(N):
    w, x = map(int, input().split())
    W.append(w)
    X.append(x)

max_count = 0
for j in range(24):
    count = 0
    for i in range(N):
        now_time = (X[i] + j) % 24
        if (now_time >= 9) and (now_time <= 18):
            count += W[i]
    max_count = max(max_count, count)
print(max_count)



import subprocess
import sys


def test_condefects_0():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='5 2\n3 4 1 3 4\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = 'Yes\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_1():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='5 3\n3 4 1 3 4\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = 'No\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_2():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='7 5\n1 2 3 4 5 5 10\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = 'Yes\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_3():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='9 7\n492686568 189330739 303238506 317063340 404539679 492601449 462224593 125660016 650287940\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = 'No\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_4():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='10 3\n215208399 131381221 215208399 37119022 298309896 346948152 346948152 208032501 138344965 190870607\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = 'Yes\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )



"""Safe serialization with smart array handling."""

from __future__ import annotations

import inspect
import re
from re import Pattern
from typing import Any

from .config import SnapshotConfig

JsonLike = None | bool | int | float | str | dict[str, Any] | list[Any]


def compile_redactors(patterns: tuple) -> list[Pattern[str]]:
    """Compile regex patterns for redaction."""
    compiled = []
    for p in patterns:
        if isinstance(p, str):
            try:
                compiled.append(re.compile(p))
            except re.error as e:
                import sys

                sys.stderr.write(f"llmdebug: invalid redaction pattern {p!r}: {e}\n")
        else:
            compiled.append(p)
    return compiled


def redact_text(text: str, redactors: list[Pattern[str]]) -> str:
    """Apply redaction patterns to text."""
    for rx in redactors:
        text = rx.sub("[REDACTED]", text)
    return text


def redact_jsonlike(
    value: JsonLike,
    redactors: list[Pattern[str]],
    *,
    redact_keys: bool = False,
) -> JsonLike:
    """Recursively redact only string leaf values in JSON-like data.

    This avoids the fragile serialize-then-regex-then-parse flow, where
    aggressive patterns can corrupt JSON structure.
    """
    if isinstance(value, str):
        return redact_text(value, redactors)
    if isinstance(value, list):
        return [redact_jsonlike(item, redactors, redact_keys=redact_keys) for item in value]
    if isinstance(value, dict):
        out: dict[str, Any] = {}
        for key, item in value.items():
            redacted_key = redact_text(key, redactors) if redact_keys else key
            out[redacted_key] = redact_jsonlike(item, redactors, redact_keys=redact_keys)
        return out
    return value


def truncate_str(s: str, max_len: int) -> str:
    """Truncate string with marker."""
    if len(s) <= max_len:
        return s
    return s[: max_len - 12] + "...[TRUNC]"


def safe_repr(x: Any, cfg: SnapshotConfig) -> str:
    """Get repr with fallback for unreprable objects."""
    try:
        r = repr(x)
    except Exception:
        r = f"<unreprable {type(x).__name__}>"
    return truncate_str(r, cfg.max_str)


def is_array_like(x: Any) -> bool:
    """Check if object is an array type (numpy, jax, torch, etc)."""
    module = type(x).__module__
    return any(
        module.startswith(prefix) for prefix in ("numpy", "jax", "torch", "tensorflow", "cupy")
    ) and hasattr(x, "shape")


def is_dataframe(x: Any) -> bool:
    """Check if object is a pandas DataFrame."""
    return type(x).__module__.startswith("pandas") and type(x).__name__ == "DataFrame"


def is_series(x: Any) -> bool:
    """Check if object is a pandas Series."""
    return type(x).__module__.startswith("pandas") and type(x).__name__ == "Series"


def get_tensor_device(arr: Any) -> str | None:
    """Get device string for PyTorch/JAX tensors.

    Returns None for CPU (default) or if device cannot be determined.
    Only returns non-None for non-CPU devices to highlight noteworthy info.
    """
    try:
        # PyTorch: arr.device -> device(type='cuda', index=0)
        if hasattr(arr, "device"):
            device = arr.device
            # PyTorch device object
            if hasattr(device, "type"):
                if device.type != "cpu":
                    return str(device)
                return None
            # JAX SingleDeviceSharding or similar
            device_str = str(device)
            if "cpu" not in device_str.lower():
                return device_str
            return None
        # JAX: arr.devices() -> {gpu(id=0)}
        if hasattr(arr, "devices"):
            devices = arr.devices()
            if devices:
                # Check if any non-CPU device
                devices_str = str(devices)
                if "cpu" not in devices_str.lower():
                    return devices_str
    except Exception:  # nosec B110 — safe serialization fallback
        pass
    return None


def get_requires_grad(arr: Any) -> bool | None:
    """Check if tensor requires gradients (PyTorch only).

    Returns True only if requires_grad is True, None otherwise.
    """
    try:
        if hasattr(arr, "requires_grad") and arr.requires_grad:
            return True
    except Exception:  # nosec B110 — safe serialization fallback
        pass
    return None


def count_anomalies(arr: Any) -> dict[str, int] | None:
    """Count NaN and Inf values in tensor.

    Returns dict with counts only if anomalies exist, None otherwise.
    Works with NumPy, PyTorch, and JAX arrays.
    """
    try:
        module = type(arr).__module__

        nan_count = 0
        inf_count = 0

        if module.startswith("torch"):
            # PyTorch
            import torch  # type: ignore[import-not-found]

            nan_count = int(torch.isnan(arr).sum().item())
            inf_count = int(torch.isinf(arr).sum().item())
        elif module.startswith("jax"):
            # JAX
            import jax.numpy as jnp  # type: ignore[import-not-found]

            nan_count = int(jnp.isnan(arr).sum())
            inf_count = int(jnp.isinf(arr).sum())
        elif module.startswith("numpy"):
            # NumPy
            import numpy as np

            nan_count = int(np.isnan(arr).sum())
            inf_count = int(np.isinf(arr).sum())
        else:
            return None

        if nan_count > 0 or inf_count > 0:
            result: dict[str, int] = {}
            if nan_count > 0:
                result["nan"] = nan_count
            if inf_count > 0:
                result["inf"] = inf_count
            return result
    except Exception:  # nosec B110 — safe serialization fallback
        pass
    return None


def compute_array_stats(arr: Any) -> dict[str, float] | None:
    """Compute min/max/mean/std statistics for numeric arrays.

    Returns:
        Dict with statistics rounded to 6 decimal places, or None if not applicable.
        Returns None for empty arrays, non-numeric dtypes, or on error.
    """
    try:
        module = type(arr).__module__

        # Check if numeric dtype
        dtype_str = str(getattr(arr, "dtype", ""))
        # Complex types are intentionally excluded: "min/max/mean/std" are ambiguous
        # without choosing a projection (real/imag/magnitude), and converting to float
        # would silently drop information.
        if not any(t in dtype_str for t in ("float", "int", "uint")):
            return None

        # Check for empty array
        if hasattr(arr, "size") and arr.size == 0:
            return None

        if module.startswith("torch"):
            # PyTorch - move to CPU for stats
            import torch  # type: ignore[import-not-found]

            arr_cpu = arr.detach().cpu().float()
            return {
                "min": round(float(torch.min(arr_cpu).item()), 6),
                "max": round(float(torch.max(arr_cpu).item()), 6),
                "mean": round(float(torch.mean(arr_cpu).item()), 6),
                # Match NumPy/JAX default semantics (population std, not unbiased).
                "std": round(float(torch.std(arr_cpu, unbiased=False).item()), 6),
            }
        elif module.startswith("jax"):
            # JAX
            import jax.numpy as jnp  # type: ignore[import-not-found]

            arr_float = arr.astype(jnp.float32)
            return {
                "min": round(float(jnp.min(arr_float)), 6),
                "max": round(float(jnp.max(arr_float)), 6),
                "mean": round(float(jnp.mean(arr_float)), 6),
                "std": round(float(jnp.std(arr_float)), 6),
            }
        elif module.startswith(("numpy", "cupy")):
            # NumPy/CuPy
            import numpy as np

            # Handle CuPy by converting to numpy
            if module.startswith("cupy"):
                arr = arr.get()
            arr_float = arr.astype(np.float64)
            return {
                "min": round(float(np.min(arr_float)), 6),
                "max": round(float(np.max(arr_float)), 6),
                "mean": round(float(np.mean(arr_float)), 6),
                "std": round(float(np.std(arr_float)), 6),
            }
    except Exception:  # nosec B110 — safe serialization fallback
        pass
    return None


def summarize_array(arr: Any, cfg: SnapshotConfig) -> dict:
    """Summarize an array-like object.

    Returns basic info (type, shape, dtype, head) plus ML-specific metadata:
    - device: only if non-CPU (highlights CUDA/TPU tensors)
    - requires_grad: only if True (highlights trainable tensors)
    - anomalies: NaN/Inf counts only if present (highlights corruption)
    """
    type_name = f"{type(arr).__module__}.{type(arr).__name__}"
    summary: dict[str, Any] = {"__array__": type_name}

    if hasattr(arr, "shape"):
        try:
            summary["shape"] = list(arr.shape)
        except Exception as e:
            summary["shape"] = f"<error: {type(e).__name__}>"

    if hasattr(arr, "dtype"):
        try:
            summary["dtype"] = str(arr.dtype)
        except Exception as e:
            summary["dtype"] = f"<error: {type(e).__name__}>"

    # Sample first N elements
    try:
        flat = arr.flatten() if hasattr(arr, "flatten") else arr.ravel()
        sample = [float(x) for x in flat[:5]]
        summary["head"] = sample
        if len(flat) > 5:
            summary["head_truncated"] = True
    except Exception as e:
        summary["head"] = f"<error: {type(e).__name__}>"

    # ML-specific metadata (only include if noteworthy)
    device = get_tensor_device(arr)
    if device is not None:
        summary["device"] = device

    requires_grad = get_requires_grad(arr)
    if requires_grad:
        summary["requires_grad"] = True

    anomalies = count_anomalies(arr)
    if anomalies:
        summary["anomalies"] = anomalies

    # Optional statistical summaries
    if cfg.include_array_stats:
        stats = compute_array_stats(arr)
        if stats:
            summary["stats"] = stats

    return summary


def summarize_dataframe(df: Any, cfg: SnapshotConfig) -> dict:
    """Summarize a pandas DataFrame."""
    summary: dict[str, Any] = {"__dataframe__": True}

    try:
        summary["shape"] = list(df.shape)
    except Exception as e:
        summary["shape"] = f"<error: {type(e).__name__}>"

    try:
        summary["columns"] = list(df.columns)[: cfg.max_items]
        if len(df.columns) > cfg.max_items:
            summary["columns_truncated"] = True
    except Exception as e:
        summary["columns"] = f"<error: {type(e).__name__}>"

    try:
        head_rows = min(3, len(df))
        summary["head"] = df.head(head_rows).values.tolist()
    except Exception as e:
        summary["head"] = f"<error: {type(e).__name__}>"

    return summary


def summarize_series(series: Any, cfg: SnapshotConfig) -> dict:
    """Summarize a pandas Series."""
    summary: dict[str, Any] = {"__series__": True}

    try:
        summary["shape"] = list(series.shape)
    except Exception as e:
        summary["shape"] = f"<error: {type(e).__name__}>"

    if hasattr(series, "name") and series.name is not None:
        summary["name"] = str(series.name)

    if hasattr(series, "dtype"):
        summary["dtype"] = str(series.dtype)

    try:
        summary["head"] = series.head(5).tolist()
        if len(series) > 5:
            summary["head_truncated"] = True
    except Exception as e:
        summary["head"] = f"<error: {type(e).__name__}>"

    return summary


def to_jsonlike(x: Any, cfg: SnapshotConfig, depth: int = 0) -> JsonLike:
    """Convert arbitrary Python object to JSON-serializable form."""
    # Primitives
    if x is None or isinstance(x, (bool, int, float)):
        return x
    if isinstance(x, str):
        return truncate_str(x, cfg.max_str)

    # Max depth reached
    if depth >= 2:
        return safe_repr(x, cfg)

    # Special types
    if is_array_like(x):
        return summarize_array(x, cfg)
    if is_dataframe(x):
        return summarize_dataframe(x, cfg)
    if is_series(x):
        return summarize_series(x, cfg)

    # Collections
    if isinstance(x, (list, tuple, set, frozenset)):
        truncated = False

        if isinstance(x, (list, tuple)):
            items = x[: cfg.max_items + 1]
        else:
            # Sort set-like values for deterministic snapshot output and diffs.
            ordered_items = sorted(
                x,
                key=lambda item: (
                    type(item).__module__,
                    type(item).__name__,
                    safe_repr(item, cfg),
                ),
            )
            items = ordered_items[: cfg.max_items + 1]

        if len(items) > cfg.max_items:
            truncated = True
            items = items[: cfg.max_items]

        result = [to_jsonlike(i, cfg, depth + 1) for i in items]
        if truncated:
            result.append("...[TRUNC]")
        return result

    if isinstance(x, dict):
        out: dict[str, Any] = {}
        for i, (k, v) in enumerate(x.items()):
            if i >= cfg.max_items:
                out["...[TRUNC]"] = f"+{len(x) - cfg.max_items} more keys"
                break
            out[safe_repr(k, cfg)] = to_jsonlike(v, cfg, depth + 1)
        return out

    # Objects with __dict__
    if hasattr(x, "__dict__") and depth < 1:
        d = getattr(x, "__dict__", {})
        if isinstance(d, dict):
            out = {"__type__": type(x).__name__}
            for i, (k, v) in enumerate(d.items()):
                if i >= min(cfg.max_items, 20):
                    out["...[TRUNC]"] = "more fields omitted"
                    break
                out[str(k)] = to_jsonlike(v, cfg, depth + 1)
            return out

    return safe_repr(x, cfg)


def serialize_locals(local_vars: dict, cfg: SnapshotConfig, redactors: list[Pattern[str]]) -> dict:
    """Serialize local variables with redaction."""
    result, _, _ = serialize_locals_with_stats(local_vars, cfg, redactors)
    return result


def serialize_locals_with_stats(
    local_vars: dict, cfg: SnapshotConfig, redactors: list[Pattern[str]]
) -> tuple[dict[str, Any], bool, int]:
    """Serialize local variables with redaction and truncation stats."""
    result: dict[str, Any] = {}
    total_count: int | None = None
    try:
        total_count = len(local_vars)
    except Exception:
        total_count = None

    for i, (k, v) in enumerate(local_vars.items()):
        if i >= cfg.max_items:
            break
        # Skip modules, functions, classes
        if inspect.ismodule(v) or inspect.isfunction(v) or inspect.isclass(v):
            result[k] = f"<{type(v).__name__}>"
        else:
            result[k] = to_jsonlike(v, cfg)

    # Apply redaction safely to string leaves only.
    # redact_jsonlike preserves structure: dict in -> dict out.
    cleaned = redact_jsonlike(result, redactors, redact_keys=cfg.redact_keys)
    if not isinstance(cleaned, dict):
        raise TypeError(f"redact_jsonlike returned {type(cleaned).__name__}, expected dict")

    truncated = False
    truncated_keys = 0
    if total_count is not None and total_count > cfg.max_items:
        truncated = True
        truncated_keys = total_count - cfg.max_items

    return cleaned, truncated, truncated_keys


def locals_metadata(local_vars: dict, cfg: SnapshotConfig) -> dict[str, dict[str, Any]]:
    """Lightweight metadata for local variables (type + size hints)."""
    meta: dict[str, dict[str, Any]] = {}

    for i, (k, v) in enumerate(local_vars.items()):
        if i >= cfg.max_items:
            break

        entry: dict[str, Any] = {
            "type": f"{type(v).__module__}.{type(v).__name__}",
        }

        # Length hints for common containers/strings
        try:
            entry["len"] = len(v)  # type: ignore[arg-type]
        except Exception:  # nosec B110 — safe serialization fallback
            pass  # len() not supported — omit, not an error

        # Array/dataframe/series shape hints (redundant but quick to scan)
        if (is_array_like(v) or is_dataframe(v) or is_series(v)) and hasattr(v, "shape"):
            try:
                entry["shape"] = list(v.shape)
            except Exception as e:
                entry["shape"] = f"<error: {type(e).__name__}>"

        meta[str(k)] = entry

    return meta



n, k = map(int, input().split())
pq = []
p = list(map(int, input().split()))
q = list(map(int, input().split()))
for i in range(n):
    pq.append((p[i], q[i]))
pq.sort()

a = []
for i in range(n):
    a.append(pq[i][1])

# dp[i][j][m] = 数列のi番目まで考えて、今後jより大の数字はNGとなるようなもので数字をm個選んでいるような選び方
dp = [[[0] * (n + 1) for _ in range(n + 2)] for _ in range(n)]
mod = 998244353

for i in range(n):
    x = a[i]
    if i == 0:
        dp[i][n + 1][1] = 1
        dp[i][x][0] = 1

    else:
        # xを採用する場合
        for j in range(x + 1, n + 2):
            for m in range(n):
                dp[i][j][m + 1] += dp[i - 1][j][m]
                dp[i][j][m + 1] %= mod
        # xを採用しない場合
        for j in range(n + 2):
            for m in range(n + 1):
                dp[i][min(x, j)][m] += dp[i - 1][j][m]
                dp[i][min(x, j)][m] %= mod

ans = 0
for j in range(n + 1):
    ans += dp[-1][j][k]
    ans %= mod

print(ans)



import subprocess
import sys


def test_condefects_0():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='900\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '999\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_1():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='901\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '1000\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_2():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='1225\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '1360\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_3():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='99999\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '111105\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_4():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='314159265358979323846264338327950288419716939937510\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '349065850398865915384738153697722542688574377708317\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )



N, M = map(int, input().split())
A = list(map(int, input().split()))
X = [list(map(int, input().split())) for _ in range(N)]
for m in range(M):
    a = 0
    for n in range(N):
        a += X[n][m]
    if a <= A[m]:
        print("No")
        exit(0)
print("Yes")



"""Tests for RCA verification gate behavior."""

from __future__ import annotations

from llmdebug.gates import evaluate_gate


def test_soft_mode_warns_but_allows_missing_requirements() -> None:
    feedback = evaluate_gate(
        mode="soft",
        current_state="captured",
        action="plan",
        payload={
            "evidence_refs": [],
            "hypothesis": "",
            "experiment_plan": "",
        },
    )
    assert feedback.allowed is True
    assert feedback.severity == "warning"
    assert "evidence_required" in feedback.triggered_checks
    assert "hypothesis_required" in feedback.triggered_checks


def test_strict_mode_blocks_missing_requirements() -> None:
    feedback = evaluate_gate(
        mode="strict",
        current_state="captured",
        action="change",
        payload={
            "evidence_refs": [],
            "hypothesis": "",
            "experiment_plan": "",
        },
    )
    assert feedback.allowed is False
    assert feedback.severity == "error"
    assert "evidence_required" in feedback.triggered_checks
    assert "hypothesis_required" in feedback.triggered_checks


def test_strict_mode_exploratory_override_allows() -> None:
    feedback = evaluate_gate(
        mode="strict",
        current_state="captured",
        action="change",
        payload={
            "evidence_refs": [],
            "hypothesis": "",
            "experiment_plan": "",
            "exploratory": True,
            "override_reason": "Need a probe to inspect runtime branch.",
        },
    )
    assert feedback.allowed is True
    assert feedback.severity == "warning"
    assert any("override accepted" in warning.lower() for warning in feedback.warnings)


def test_loop_protection_warning_after_repeats() -> None:
    feedback = evaluate_gate(
        mode="soft",
        current_state="changed",
        action="change",
        payload={
            "evidence_refs": ["crash_frame:app.py:42:parse_input"],
            "hypothesis": "Input parsing fails on non-digit value.",
            "experiment_plan": "Guard int conversion with try/except.",
            "hypothesis_advanced": False,
        },
        repeated_signature_count=4,
        exploration_budget=2,
    )
    assert feedback.allowed is True
    assert "loop_protection" in feedback.triggered_checks
    assert any("repeated" in warning.lower() for warning in feedback.warnings)



n = int(input())
phrase = input().lower()
operation = int(input())

alphabet = "abcdefghijklmnopqrstuvwsyz"

for i in range(operation):
    original, become = input().split()
    alphabet = alphabet.replace(original, become)

new = ""

for ch in phrase:
    new += alphabet[ord(ch) - 97]
print(new)



from typing import List, Optional, Tuple, Dict, Set
from collections import defaultdict, Counter, deque
import heapq
import math
import bisect
import itertools
import functools


class Solution:
    def arrayChange(self, nums: List[int], operations: List[List[int]]) -> List[int]:
        index_map = defaultdict(int)
        for i, n in enumerate(nums):
            index_map[n] = i

        for op in operations:
            n1, n2 = op
            nums[index_map[n1]] = n2
            new_obj = UndefinedObject()

        return nums



def generate_substrings(s):
    substrings = []
    n = len(s)
    for length in range(1, n + 1):  # 長さ1からnまでの部分文字列を生成する
        for start in range(n - length + 1):
            substr = s[start : start + length]
            substrings.append(substr)
    return substrings


s = input()
print(len(generate_substrings(s)))



from typing import List, Optional, Tuple, Dict, Set
from collections import defaultdict, Counter, deque
import heapq
import math
import bisect
import itertools
import functools
class NumArray:

    def __init__(self, nums: List[int]):
    self.nums=[0]+list(accumulate(nums))
    print(self.nums)

    def sumRange(self, left: int, right: int) -> int:
        return self.nums[right+1]-self.nums[left]

# Your NumArray object will be instantiated and called as such:
# obj = NumArray(nums)
# param_1 = obj.sumRange(left,right)



import subprocess
import sys


def test_condefects_0():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='2 3\n1 2 3\n8 9 10\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = 'Yes\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_1():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='2 1\n1\n2\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = 'No\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_2():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='10 4\n1346 1347 1348 1349\n1353 1354 1355 1356\n1360 1361 1362 1363\n1367 1368 1369 1370\n1374 1375 1376 1377\n1381 1382 1383 1384\n1388 1389 1390 1391\n1395 1396 1397 1398\n1402 1403 1404 1405\n1409 1410 1411 1412\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = 'Yes\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_3():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='1 7\n789335564 749650823 914426362 880284765 939766774 688515116 148723218\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = 'No\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_4():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='1 1\n907309233\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = 'Yes\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )



s = list(input())
max = 0
for i in range(len(s)):
    for j in range(i + 1, len(s)):
        x = s[i:j]
        x.reverse()
        if s[i:j] == x and max < j - i:
            max = j - i
print("{}".format(max))



from typing import List, Optional, Tuple, Dict, Set
from collections import defaultdict, Counter, deque
import heapq
import math
import bisect
import itertools
import functools


class Solution:
    def numberOfArithmeticSlices(self, nums: List[int]) -> int:
        n = len(nums)
        ans = 0
        dp = defaultdict(Counter)
        for i in range(1, n):
            for j in range(i):
                d = nums[i] - nums[j]
                dp[i][d] += dp[j][d]
            ans += sum(dp[i].values()) - i
        return ans



from itertools import combinations

N, M, K = map(int, input().split())

edge = []
for _ in range(M):
    u, v, w = map(int, input().split())
    edge.append([u - 1, v - 1, w])


def find(x):
    if R[x] < 0:
        return x
    else:
        R[x] = find(R[x])
        return R[x]


def unite(root_a, root_b):
    if root_a != root_b:
        if R[root_a] > R[root_b]:
            R[root_a] = root_b
        elif R[root_b] > R[root_a]:
            R[root_b] = root_a
        elif R[root_a] == R[root_b]:
            R[root_b] = root_a
            R[root_a] -= 1


def group_size(R):
    count = 0
    for r in R:
        if r < 0:
            count += 1
    return count


ans = 10**10
for edges in combinations(edge, N - 1):  # 辺の数はN-1本でいい
    R = [-1] * N
    cost = 0
    for edge in edges:
        u, v, w = edge
        root_u = find(u)
        root_v = find(v)
        unite(root_u, root_v)
        cost += w
    if group_size(R) == 1:
        ans = min(cost % K, ans)

print(ans)



import sys

# sys.setrecursionlimit(1000005)
# sys.set_int_max_str_digits(200005)
int1 = lambda x: int(x) - 1
pDB = lambda *x: print(*x, end="\n", file=sys.stderr)
p2D = lambda x: print(*x, sep="\n", end="\n\n", file=sys.stderr)


def II():
    return int(sys.stdin.readline())


def LI():
    return list(map(int, sys.stdin.readline().split()))


def LLI(rows_number):
    return [LI() for _ in range(rows_number)]


def LI1():
    return list(map(int1, sys.stdin.readline().split()))


def LLI1(rows_number):
    return [LI1() for _ in range(rows_number)]


def SI():
    return sys.stdin.readline().rstrip()


dij = [(0, 1), (-1, 0), (0, -1), (1, 0)]
# dij = [(0, 1), (-1, 0), (0, -1), (1, 0), (1, 1), (1, -1), (-1, 1), (-1, -1)]
# inf = -1-(-1 << 31)
inf = -1 - (-1 << 62)

# md = 10**9+7
md = 998244353


def tobig(x, y):
    i, j = x // k, y // k
    x %= k
    y %= k
    if i & 1 == j & 1:
        res = []
        res.append((i - 1, j, x + 1))
        res.append((i, j - 1, y + 1))
        res.append((i + 1, j, k - x))
        res.append((i, j + 1, k - y))
        return res
    return [(i, j, 0)]


k = II()
sx, sy = LI()
tx, ty = LI()
ss = tobig(sx, sy)
tt = tobig(tx, ty)
ans = abs(sx - tx) + abs(sy - ty)
for a, b, d in ss:
    for i, j, e in tt:
        x, y = abs(a - i), abs(b - j)
        if x > y:
            x, y = y, x
        ans = min(ans, y * 2 + d + e)
        ans = min(ans, x * 2 + (y - x) * (k + 1) + d + e)
print(ans)



from typing import List, Optional, Tuple, Dict, Set
from collections import defaultdict, Counter, deque
import heapq
import math
import bisect
import itertools
import functools


class Solution:
    def minBitFlips(self, start: int, goal: int) -> int:
        s = bin(start)[2:].zfill(50)
        g = bin(goal)[2:].zfill(50)
        count = 0
        for i in range(50):
            if s[i] != g[i]:
                count += 1
        self.some_undefined_method(count)



from buggy import Solution


def test_case_0():
    sol = Solution()
    result = sol.longestWPI([9,9,6,0,6,6,9])
    assert result == 3


def test_case_1():
    sol = Solution()
    result = sol.longestWPI([6,6,6])
    assert result == 0



"""Shared text formatting helpers used by CLI and MCP server.

This is an internal module (leading underscore). Functions are public
so they can be imported by cli.py and mcp_server.py.
"""

from __future__ import annotations

from typing import Any


def build_source_text(source: dict[str, Any], crash_line: int) -> str:
    """Build a source snippet string with arrow marker on crash line."""
    snippet = source.get("snippet", [])
    lines: list[str] = []
    for entry in snippet:
        lineno = entry.get("lineno", 0)
        code = entry.get("code", "")
        marker = " \u2192 " if lineno == crash_line else "   "
        lines.append(f"{marker}{lineno:>4} | {code}")
    return "\n".join(lines)


def format_local_value(key: str, value: Any, meta: dict[str, Any] | None) -> tuple[str, str, str]:
    """Format a single local variable for display. Returns (name, type_str, value_str)."""
    type_str = ""
    if meta:
        type_str = meta.get("type", "")
        # Shorten qualified types
        if "." in type_str:
            type_str = type_str.rsplit(".", 1)[-1]

    # Format array-like values specially
    if isinstance(value, dict):
        for array_key in ("__array__", "__dataframe__", "__series__"):
            if value.get(array_key):
                dtype = value.get("dtype", "")
                shape = value.get("shape", [])
                shape_str = str(shape)
                extra = f" dtype={dtype}" if dtype else ""
                return key, array_key.strip("_"), f"{shape_str}{extra}"

    value_str = str(value) if not isinstance(value, str) else value
    if len(value_str) > 120:
        value_str = value_str[:117] + "..."
    return key, type_str, value_str


def format_git_head_section(head: Any) -> list[str]:
    """Format git HEAD info as plain text lines."""
    if not isinstance(head, dict):
        return []
    commit = str(head.get("commit") or "?")
    branch = str(head.get("branch") or "?")
    dirty = "true" if bool(head.get("dirty")) else "false"
    detached = "true" if bool(head.get("detached")) else "false"
    return [
        "## Git Head",
        f"commit: {commit}",
        f"branch: {branch}",
        f"dirty: {dirty}",
        f"detached: {detached}",
    ]


def format_crash_file_section(crash_file: Any) -> list[str]:
    """Format crash file blame/location as plain text lines."""
    if not isinstance(crash_file, dict):
        return []
    lines = [
        "",
        "## Crash File",
        f"file_rel: {crash_file.get('file_rel') or '?'!s}",
    ]
    line = crash_file.get("line")
    if line is not None:
        lines.append(f"line: {line}")
    in_repo = "true" if bool(crash_file.get("in_repo")) else "false"
    lines.append(f"in_repo: {in_repo}")
    blame = crash_file.get("blame")
    if isinstance(blame, dict):
        lines.extend(
            (
                "blame:",
                f"  commit: {blame.get('commit', '?')}",
                f"  author: {blame.get('author', '?')}",
                f"  author_time: {blame.get('author_time', '?')}",
                f"  summary: {blame.get('summary', '?')}",
            )
        )
    return lines


def format_recent_commits_section(recent_commits: Any) -> list[str]:
    """Format recent commit metadata as plain text lines."""
    if not isinstance(recent_commits, list) or not recent_commits:
        return []
    lines = ["", "## Recent Commits"]
    for idx, entry in enumerate(recent_commits, 1):
        if not isinstance(entry, dict):
            continue
        commit = str(entry.get("commit") or "?")
        author = str(entry.get("author") or "?")
        when = str(entry.get("author_time") or "?")
        summary = str(entry.get("summary") or "")
        files = int(entry.get("files_changed") or 0)
        ins = int(entry.get("insertions") or 0)
        dele = int(entry.get("deletions") or 0)
        lines.append(f"{idx}. {commit} {when} {author}")
        lines.append(f"   {summary}")
        lines.append(f"   stats: files={files} +{ins} -{dele}")
    return lines


def format_crash_diffstat_section(diffstat: Any) -> list[str]:
    """Format crash file diffstat as plain text lines."""
    if not isinstance(diffstat, dict):
        return []
    touched = "true" if bool(diffstat.get("touched")) else "false"
    return [
        "",
        "## Crash File Diffstat",
        f"files_changed: {int(diffstat.get('files_changed') or 0)}",
        f"insertions: {int(diffstat.get('insertions') or 0)}",
        f"deletions: {int(diffstat.get('deletions') or 0)}",
        f"touched: {touched}",
    ]


def format_git_warnings_section(warnings: Any) -> list[str]:
    """Format git warning lines."""
    if not isinstance(warnings, list) or not warnings:
        return []
    lines = ["", "## Warnings"]
    lines.extend(f"- {warning}" for warning in warnings)
    return lines


def format_enhanced_git_context_text(context: dict[str, Any]) -> str:
    """Render enhanced git metadata as plain text."""
    lines: list[str] = []
    sections = (
        format_git_head_section(context.get("head")),
        format_crash_file_section(context.get("crash_file")),
        format_recent_commits_section(context.get("recent_commits")),
        format_crash_diffstat_section(context.get("crash_file_diffstat")),
        format_git_warnings_section(context.get("_git_warnings")),
    )
    for section in sections:
        lines.extend(section)

    if not lines:
        return "No enhanced git metadata available."
    return "\n".join(lines)



def read():
    return list(map(int, input().strip().split()))


(n,) = read()
a = read()
S = [0 for i in range(10**6 + 5)]
selfpair = 0
for i in a:
    S[i] = 1
    if all([int(j) < 5 for j in str(i)]):
        selfpair += 1
for j in range(6):
    for i in range(10**6):
        if (i // 10**j) % 10:
            S[i] += S[i - 10**j]
ans = 0
for i in a:
    ans += S[999999 - i]
print((ans - selfpair) // 2)



import subprocess
import sys


def test_condefects_0():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='12\n31 28 31 30 31 30 31 31 30 31 30 31\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '7 2\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_1():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='1\n1\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '1 1\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_2():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='6\n3 1 4 1 5 9\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '5 3\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_3():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='1\n1\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '1 1\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_4():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='1\n99\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '1 50\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )



import subprocess
import sys


def test_condefects_0():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='2 2 7\n3 5\n6 1\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '24\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_1():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='1 3 2\n1\n1 1 1\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '6\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_2():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='7 12 25514963\n2436426 24979445 61648772 23690081 33933447 76190629 62703497\n11047202 71407775 28894325 31963982 22804784 50968417 30302156 82631932 61735902 80895728 23078537 7723857\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '2115597124\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_3():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='1 1 166048436\n92686568\n73361868\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '166048436\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_4():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='1 1 1\n1\n1\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '1\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )



import bisect
import copy
import decimal
import fractions
import heapq
import itertools
import math
import random
import sys
import time
from collections import Counter, deque, defaultdict
from functools import lru_cache, reduce
from heapq import heappush, heappop, heapify, heappushpop, _heappop_max, _heapify_max


def _heappush_max(heap, item):
    heap.append(item)
    heapq._siftdown_max(heap, 0, len(heap) - 1)


def _heappushpop_max(heap, item):
    if heap and item < heap[0]:
        item, heap[0] = heap[0], item
        heapq._siftup_max(heap, 0)
    return item


from math import gcd as GCD

read = sys.stdin.read
readline = sys.stdin.readline
readlines = sys.stdin.readlines
write = sys.stdout.write

N = int(readline())
A = list(map(int, readline().split()))
g = 0
for i in range(N - 1):
    g = GCD(g, A[i + 1] - A[i])
ans = A[0] % g + A[-1] - A[0]
print(ans)



def accumulate_tax(prices: list[float], rate: float = 0.1) -> float:
    """Sum tax amounts for each price and return the total."""
    total = 0.0
    for price in prices:
        total += price * rate
    return total


def check_tax_balance(prices: list[float], expected: float) -> bool:
    """Return True if computed tax matches expected value exactly."""
    computed = accumulate_tax(prices)
    return computed == expected



def string(s):
    if 1 <= len(s) <= 100:
        bot = 0
        for i in s:
            if i == "w":
                bot += 2
            elif i == "v":
                bot += 1
        return bot


print(string("wwwvvvvvv"))



from buggy import Solution


def test_case_0():
    sol = Solution()
    result = sol.plusOne([1,2,3])
    assert result == [1,2,4]


def test_case_1():
    sol = Solution()
    result = sol.plusOne([4,3,2,1])
    assert result == [4,3,2,2]


def test_case_2():
    sol = Solution()
    result = sol.plusOne([9])
    assert result == [1,0]



X, Y = map(int, input().split())
if X > Y:  # 下り:
    j = X - Y
    if j <= 3:
        print("Yes")
    else:
        print("No")
else:
    k = Y - X
    if k >= 2:
        print("Yes")
    else:
        print("No")



INT = lambda: int(input())
MI = lambda: map(int, input().split())
MI_DEC = lambda: map(lambda x: int(x) - 1, input().split())
LI = lambda: list(map(int, input().split()))


def main() -> None:
    n = INT()
    s = LI()
    count = 0
    for m, di in enumerate(s, start=1):
        for d in range(1, di):
            ss = set(str(m)).union(set(str(d)))
            if len(ss) == 1:
                count += 1
    print(count)


if __name__ == "__main__":
    main()



import sys

sys.setrecursionlimit(10**6)


def e(x):
    if dp[x] != -1:
        return dp[x]
    if x == 0:
        dp[x] = 0
        return 0
    if x == 1:
        dp[x] = n * (n - 1) * pow(2 * n - 1, mod - 2, mod) % mod
        return dp[x]
    inv = pow(2 * n * x - x**2, mod - 2, mod)
    res = inv * (x * (x - 1) * e(x - 2) + (2 * n * x - 2 * x * x + x) * e(x - 1) + (n - x)) % mod
    dp[x] = res
    return res


n = int(input())
mod = 998244353
dp = [-1] * (n + 1)
dp[0] = 0
e(n)
print(dp[n], dp[n - 1])



from typing import List, Optional, Tuple, Dict, Set
from collections import defaultdict, Counter, deque
import heapq
import math
import bisect
import itertools
import functools


class Solution:
    def numberOfArithmeticSlices(self, nums: List[int]) -> int:
        total, n = 0, len(nums)
        dp = [defaultdict(int) for _ in nums]
        for i in range(1, n):
            for j in range(i):
                diff = nums[j] - nums[i]
                dp[i][diff] += dp[j][diff] + 1
                total += self.undifned_method(dp[j][diff])
        return total
